@@ -1,5 +1,5 @@
 #
-# $Id: Smtp.pm,v 19287c1db8d3 2015/10/11 16:22:55 gomor $
+# $Id: Smtp.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # audit::smtp Brik
 #
@@ -11,16 +11,21 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 19287c1db8d3 $',
-      tags => [ qw(unstable audit smtp) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          hostname => [ qw(hostname) ],
          port => [ qw(integer) ],
          domainname => [ qw(domainname) ],
          _smtp => [ qw(INTERNAL) ],
       },
+      attributes_default => {
+         port => 25,
+      },
       commands => {
-         connect => [ ],
+         connect => [ qw(hostname|OPTIONAL port|OPTIONAL domainname|OPTIONAL) ],
          banner => [ ],
          quit => [ ],
          open_auth_login => [ ],
@@ -40,18 +45,21 @@ sub brik_use_properties {
    return {
       attributes_default => {
          hostname => $self->global->hostname,
-         domainname => $self->global->domainname,
-         port => 25,
       },
    };
 }
 
 sub connect {
    my $self = shift;
+   my ($hostname, $port, $domainname) = @_;
+
+   $hostname ||= $self->hostname;
+   $port ||= $self->port;
+   $domainname ||= $self->domainname;
+   $self->brik_help_run_undef_arg('connect', $hostname) or return;
+   $self->brik_help_run_undef_arg('connect', $port) or return;
+   $self->brik_help_run_undef_arg('connect', $domainname) or return;
 
-   my $hostname = $self->hostname;
-   my $port = $self->port;
-   my $domainname = $self->domainname;
    my $timeout = $self->global->ctimeout;
 
    my $smtp = Net::SMTP->new(
@@ -70,11 +78,9 @@ sub connect {
 sub quit {
    my $self = shift;
 
-   if (! defined($self->_smtp)) {
-      return $self->log->error($self->brik_help_run('connect'));
-   }
-
    my $smtp = $self->_smtp;
+   $self->brik_help_run_undef_arg('connect', $smtp) or return;
+
    $self->_smtp(undef);
 
    return $smtp->quit;
@@ -83,11 +89,8 @@ sub quit {
 sub banner {
    my $self = shift;
 
-   if (! defined($self->_smtp)) {
-      return $self->log->error($self->brik_help_run('connect'));
-   }
-
    my $smtp = $self->_smtp;
+   $self->brik_help_run_undef_arg('connect', $smtp) or return;
 
    chomp(my $banner = $smtp->banner);
 
@@ -107,11 +110,8 @@ sub banner {
 sub open_auth_login {
    my $self = shift;
 
-   if (! defined($self->_smtp)) {
-      return $self->log->error($self->brik_help_run('connect'));
-   }
-
    my $smtp = $self->_smtp;
+   $self->brik_help_run_undef_arg('connect', $smtp) or return;
 
    my $smtp_feature_auth_login = 0;
    my $smtp_open_auth_login = 0;
@@ -144,11 +144,8 @@ sub open_auth_login {
 sub open_relay {
    my $self = shift;
 
-   if (! defined($self->_smtp)) {
-      return $self->log->error($self->brik_help_run('connect'));
-   }
-
    my $smtp = $self->_smtp;
+   $self->brik_help_run_undef_arg('connect', $smtp) or return;
 
    my $smtp_open_relay = 0;
    my $smtp_to_reject = 0;
@@ -223,7 +220,7 @@ Metabrik::Audit::Smtp - audit::smtp Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
