@@ -1,5 +1,5 @@
 #
-# $Id: Tool.pm,v 7d4af34f011c 2016/04/12 05:55:37 gomor $
+# $Id: Tool.pm,v 57fc7992fc3a 2016/10/05 05:25:58 gomor $
 #
 # brik::tool Brik
 #
@@ -11,13 +11,14 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 7d4af34f011c $',
+      revision => '$Revision: 57fc7992fc3a $',
       tags => [ qw(unstable program) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          repository => [ qw(Repository) ],
+         _done => [ qw(INTERNAL) ],  # Used to stored already recursively processed stuff
       },
       attributes_default => {
          use_pager => 1,
@@ -276,25 +277,42 @@ sub get_brik_hierarchy_recursive {
 
    $self->brik_help_run_undef_arg('get_brik_hierarchy_recursive', $brik) or return;
 
+   # XXX: rewrite using get_brik_hierarchy + get_require_briks
+   # get_require_briks_recursive works OK
+
    # We first gather our own Brik hierarchy
-   my %hierarchy = ();
+   #my %hierarchy = ();
+   if (exists($self->{_done}{$brik})) {
+      #return;
+      return [ sort { $a cmp $b } keys %{$self->{_done}} ];
+   }
+
    my $mine = $self->get_brik_hierarchy($brik) or return;
+   $self->{_done}{$brik}++;
    for (@$mine) {
-      $hierarchy{$_}++;
+      $self->log->info("get_brik [$_]");
+      #$hierarchy{$_}++;
+      $self->{_done}{$_}++;
    }
 
    # Then we search for all required Briks recursively
    my $require_briks = $self->get_require_briks($brik) or return;
    for my $this (@$require_briks) {
-      #$self->log->info("require_brik [$this]");
-      $hierarchy{$this}++;
-      my $this_hierarchy = $self->get_brik_hierarchy_recursive($this) or next;
-      for (@$this_hierarchy) {
-         $hierarchy{$_}++;
+      #if (! exists($hierarchy{$this})) {
+      if (! exists($self->{_done}{$this})) {
+         $self->log->info("require_brik [$this]");
+         my $this_hierarchy = $self->get_brik_hierarchy_recursive($this) or next;
+         #$hierarchy{$this}++;
+         $self->{_done}{$this}++;
+         for (@$this_hierarchy) {
+            #$hierarchy{$_}++;
+            $self->{_done}{$_}++;
+         }
       }
    }
 
-   return [ sort { $a cmp $b } keys %hierarchy ];
+   #return [ sort { $a cmp $b } keys %hierarchy ];
+   return [ sort { $a cmp $b } keys %{$self->{_done}} ];
 }
 
 sub install_all_need_packages {
@@ -417,7 +435,9 @@ exit(0);
 EOF
 ;
 
-   return $ft->write($data, $filename);
+   $ft->write($data, $filename) or return;
+
+   return $filename;
 }
 
 sub create_brik {
@@ -568,7 +588,9 @@ Patrice E<lt>GomoRE<gt> Auffret
 EOF
 ;
 
-   return $ft->write($data, $filename);
+   $ft->write($data, $filename) or return;
+
+   return $filename;
 }
 
 sub update_core {
@@ -605,7 +627,7 @@ sub update_repository {
    # If we define the core::global repository Attribute, we use that as 
    # a local repository. We will not install Metabrik::Repository in that case.
    my $datadir = $self->datadir;
-   my $repository = $self->global->repository || $datadir.'/repository';
+   my $repository = $datadir.'/repository';
 
    my $url = 'https://www.metabrik.org/hg/repository';
 
