@@ -1,5 +1,5 @@
 #
-# $Id: Rest.pm,v 629ac2fb6bcb 2016/02/13 17:10:24 gomor $
+# $Id: Rest.pm,v 75fc1a5bf385 2016/09/28 05:57:21 gomor $
 #
 # client::rest Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Client::Www);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 629ac2fb6bcb $',
+      revision => '$Revision: 75fc1a5bf385 $',
       tags => [ qw(unstable http api) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -35,7 +35,7 @@ sub brik_properties {
          delete => [ qw(uri|OPTIONAL username|OPTIONAL password|OPTIONAL) ],
          options => [ qw(uri|OPTIONAL username|OPTIONAL password|OPTIONAL) ],
          code => [ ],
-         content => [ ],
+         content => [ qw(output_mode|OPTIONAL) ],
       },
       require_modules => {
          'Metabrik::String::Xml' => [ ],
@@ -46,6 +46,7 @@ sub brik_properties {
 
 sub content {
    my $self = shift;
+   my ($output_mode) = @_;
 
    my $last = $self->_last;
    if (! defined($last)) {
@@ -53,7 +54,7 @@ sub content {
    }
 
    my $sm;
-   my $output_mode = $self->output_mode;
+   $output_mode ||= $self->output_mode;
    if ($output_mode eq 'json') {
       $sm = Metabrik::String::Json->new_from_brik_init($self) or return;
    }
