@@ -1,5 +1,5 @@
 #
-# $Id: Ssh.pm,v 887d85a7f604 2015/11/12 14:44:58 gomor $
+# $Id: Ssh.pm,v 584b8f5239cf 2016/02/09 07:24:59 gomor $
 #
 # client::ssh Brik
 #
@@ -7,12 +7,14 @@ package Metabrik::Client::Ssh;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 887d85a7f604 $',
-      tags => [ qw(unstable client ssh) ],
+      revision => '$Revision: 584b8f5239cf $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          hostname => [ qw(hostname) ],
          port => [ qw(integer) ],
@@ -25,30 +27,39 @@ sub brik_properties {
          _channel => [ qw(INTERNAL) ],
       },
       attributes_default => {
-         hostname => 'localhost',
          username => 'root',
          port => 22,
          use_publickey => 1,
       },
       commands => {
+         install => [ ], # Inherited
          connect => [ qw(hostname|OPTIONAL port|OPTIONAL username|OPTIONAL) ],
-         cat => [ qw(file) ],
-         exec => [ qw(command) ],
-         read => [ ],
-         read_line => [ ],
-         read_line_all => [ ],
+         execute => [ qw(command) ],
+         read => [ qw(channel|OPTIONAL) ],
+         read_line => [ qw(channel|OPTIONAL) ],
+         read_line_all => [ qw(channel|OPTIONAL) ],
          load => [ qw(file) ],
-         listfiles => [ qw(glob) ],
          disconnect => [ ],
+         create_channel => [ ],
+         close_channel => [ ],
+         execute_in_background => [ qw(command stdout_file|OPTIONAL stderr_file|OPTIONAL stdin_file|OPTIONAL) ],
+         capture => [ qw(command) ],
       },
       require_modules => {
          'IO::Scalar' => [ ],
          'Net::SSH2' => [ ],
          'Metabrik::String::Password' => [ ],
       },
+      need_packages => {
+         ubuntu => [ qw(libssh2-1-dev) ],
+      },
    };
 }
 
+#
+# With help from http://www.perlmonks.org/?node_id=569657
+#
+
 sub connect {
    my $self = shift;
    my ($hostname, $port, $username, $password) = @_;
@@ -61,9 +72,12 @@ sub connect {
    $port ||= $self->port;
    $username ||= $self->username;
    $password ||= $self->password;
+   $self->brik_help_run_undef_arg('connect', $hostname) or return;
+   $self->brik_help_run_undef_arg('connect', $port) or return;
+   $self->brik_help_run_undef_arg('connect', $username) or return;
+
    my $publickey = $self->publickey;
    my $privatekey = $self->privatekey;
-
    if ($self->use_publickey && ! $publickey) {
       return $self->log->error($self->brik_help_set('publickey'));
    }
@@ -120,54 +134,101 @@ sub disconnect {
    my $r = $ssh2->disconnect;
 
    $self->ssh2(undef);
-   $self->_channel(undef);
+   $self->close_channel;
 
    return $r;
 }
 
-sub exec {
+sub execute {
    my $self = shift;
    my ($cmd) = @_;
 
    my $ssh2 = $self->ssh2;
-   if (! defined($ssh2)) {
-      return $self->log->error($self->brik_help_run('connect'));
-   }
-   if (! defined($cmd)) {
-      return $self->log->error($self->brik_help_run('exec'));
-   }
+   $self->brik_help_run_undef_arg('connect', $ssh2) or return;
+   $self->brik_help_run_undef_arg('execute', $cmd) or return;
 
-   $self->debug && $self->log->debug("exec: cmd [$cmd]");
+   $self->debug && $self->log->debug("execute: cmd [$cmd]");
 
-   my $channel = $ssh2->channel;
-   if (! defined($channel)) {
-      return $self->log->error("exec: channel creation error");
-   }
+   my $channel = $self->create_channel or return;
 
-   $channel->exec($cmd)
-      or return $self->log->error("exec: can't execute command [$cmd]: $!");
+   $channel->process('exec', $cmd)
+      or return $self->log->error("execute: can't execute command [$cmd]: $!");
 
    return $self->_channel($channel);
 }
 
-sub read_line {
+sub create_channel {
    my $self = shift;
 
    my $ssh2 = $self->ssh2;
-   if (! defined($ssh2)) {
-      return $self->log->error($self->brik_help_run('connect'));
+   $self->brik_help_run_undef_arg('connect', $ssh2) or return;
+
+   my $channel = $ssh2->channel;
+   if (! defined($channel)) {
+      return $self->log->error("create_channel: creation failed: [$!]");
    }
 
+   return $self->_channel($channel);
+}
+
+sub close_channel {
+   my $self = shift;
+
    my $channel = $self->_channel;
-   if (! defined($channel)) {
-      return $self->log->info("read_line: create a channel first");
+   if (defined($channel)) {
+      $channel->close;
+      $self->_channel(undef);
    }
 
+   return 1;
+}
+
+sub execute_in_background {
+   my $self = shift;
+   my ($cmd, $stdout_file, $stderr_file, $stdin_file) = @_;
+
+   my $ssh2 = $self->ssh2;
+   $self->brik_help_run_undef_arg('connect', $ssh2) or return;
+   $self->brik_help_run_undef_arg('execute_in_background', $cmd) or return;
+
+   $stdout_file ||= '/dev/null';
+   $stderr_file ||= '/dev/null';
+
+   my $channel = $self->create_channel or return;
+
+   $cmd .= " > $stdout_file 2> $stderr_file";
+   if (defined($stdin_file)) {
+      $cmd .= " < $stdin_file";
+   }
+   $cmd .= " &";
+
+   $self->debug && $self->log->debug("execute_in_background: cmd [$cmd]");
+
+   $channel->process('exec', $cmd)
+      or return $self->log->error("execute_in_background: process failed: [$!]");
+   $channel->send_eof
+      or return $self->log->error("execute_in_background: send_eof failed: [$!]");
+
+   $self->close_channel or return;
+
+   return 1;
+}
+
+sub read_line {
+   my $self = shift;
+   my ($channel) = @_;
+
+   $channel ||= $self->_channel;
+   $self->brik_help_run_undef_arg('create_channel', $channel) or return;
+
    my $read = '';
    my $count = 1;
    while (1) {
       my $char = '';
       my $rc = $channel->read($char, $count);
+      if (! defined($rc)) {
+         return $self->log->error("read_line: read failed: [$!]");
+      }
       if ($rc > 0) {
          #print "read[$char]\n";
          #print "returned[$c]\n";
@@ -188,45 +249,37 @@ sub read_line {
 
 sub read_line_all {
    my $self = shift;
+   my ($channel) = @_;
 
-   my $ssh2 = $self->ssh2;
-   if (! defined($ssh2)) {
-      return $self->log->error($self->brik_help_run('connect'));
-   }
+   $channel ||= $self->_channel;
+   $self->brik_help_run_undef_arg('create_channel', $channel) or return;
 
-   my $channel = $self->_channel;
-   if (! defined($channel)) {
-      return $self->log->info("read_line_all: create a channel first");
-   }
-
-   my $read = $self->read;
-   if (! defined($read)) {
-      return $self->log->error("read_line_all: read error");
-   }
+   my $read = $self->read($channel) or return;
 
    my @lines = split(/\n/, $read);
 
+   $self->close_channel;
+
    return \@lines;
 }
 
 sub read {
    my $self = shift;
+   my ($channel) = @_;
 
-   my $ssh2 = $self->ssh2;
-   if (! defined($ssh2)) {
-      return $self->log->error($self->brik_help_run('connect'));
-   }
+   $channel ||= $self->_channel;
+   $self->brik_help_run_undef_arg('create_channel', $channel) or return;
 
-   my $channel = $self->_channel;
-   if (! defined($channel)) {
-      return $self->log->info("read: create a channel first");
-   }
+   $self->log->verbose("read: channel[$channel]");
 
    my $read = '';
    my $count = 1024;
    while (1) {
       my $buf = '';
       my $rc = $channel->read($buf, $count);
+      if (! defined($rc)) {
+         return $self->log->error("read: read failed: [$!]");
+      }
       if ($rc > 0) {
          #print "read[$buf]\n";
          #print "returned[$c]\n";
@@ -242,61 +295,18 @@ sub read {
       }
    }
 
+   $self->close_channel;
+
    return $read;
 }
 
-sub listfiles {
-   my $self = shift;
-   my ($glob) = @_;
-
-   my $channel = $self->exec("ls $glob 2> /dev/null");
-   if (! defined($channel)) {
-      return $self->log->error("listfiles: exec error");
-   }
-
-   my $read = $self->read;
-   if (! defined($read)) {
-      return $self->log->error("listfiles: read error");
-   }
-
-   my @files = split(/\n/, $read);
-
-   return \@files;
-}
-
-sub cat {
-   my $self = shift;
-   my ($file) = @_;
-
-   if (! defined($self->ssh2)) {
-      return $self->log->error($self->brik_help_run('connect'));
-   }
-
-   if (! defined($file)) {
-      return $self->log->error($self->brik_help_run('cat'));
-   }
-
-   my $channel = $self->exec('cat '.$file);
-   if (! defined($channel)) {
-      return $self->log->error("cat: channel for file [$file]");
-   }
-
-   return $self->_channel($channel);
-}
-
 sub load {
    my $self = shift;
    my ($file) = @_;
 
-   if (! defined($self->ssh2)) {
-      return $self->log->error($self->brik_help_run('connect'));
-   }
-
-   if (! defined($file)) {
-      return $self->log->error($self->brik_help_run('load'));
-   }
-
    my $ssh2 = $self->ssh2;
+   $self->brik_help_run_undef_arg('connect', $ssh2) or return;
+   $self->brik_help_run_undef_arg('load', $file) or return;
 
    my $io = IO::Scalar->new;
 
@@ -313,6 +323,27 @@ sub load {
    return $buf;
 }
 
+sub capture {
+   my $self = shift;
+   my ($cmd) = @_;
+
+   my $ssh2 = $self->ssh2;
+   $self->brik_help_run_undef_arg('connect', $ssh2) or return;
+   $self->brik_help_run_undef_arg('capture', $cmd) or return;
+
+   my $channel = $self->create_channel or return;
+
+   $self->debug && $self->log->debug("capture: cmd [$cmd]");
+
+   $channel->process('exec', $cmd)
+      or return $self->log->error("capture: process failed: [$!]");
+
+   my $lines = $self->read_line_all or return;
+   $self->close_channel;
+
+   return $lines;
+}
+
 sub brik_fini {
    my $self = shift;
 
@@ -336,7 +367,7 @@ Metabrik::Client::Ssh - client::ssh Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
