@@ -1,5 +1,5 @@
 #
-# $Id: Ssl.pm,v e4ea19cc2aca 2015/10/16 16:49:29 gomor $
+# $Id: Ssl.pm,v 00ead8d799a8 2016/02/14 14:23:21 gomor $
 #
 # client::ssl Brik
 #
@@ -7,19 +7,22 @@ package Metabrik::Client::Ssl;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: e4ea19cc2aca $',
-      tags => [ qw(unstable client ssl tls) ],
+      revision => '$Revision: 00ead8d799a8 $',
+      tags => [ qw(unstable tls) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          uri => [ qw(uri) ],
       },
       commands => {
+         install => [ ], # Inherited
          verify_server => [ qw(uri|OPTIONAL) ],
          getcertificate => [ qw(uri|OPTIONAL) ],
-         getcertificate2 => [ qw(SCALAR SCALAR) ],
+         getcertificate2 => [ qw(host port) ],
       },
       require_modules => {
          'Data::Dumper' => [ ],
@@ -30,6 +33,9 @@ sub brik_properties {
          'Net::SSLeay' => [ ],
          'Metabrik::String::Uri' => [ ],
       },
+      need_packages => {
+         ubuntu => [ qw(libssl-dev) ],
+      },
    };
 }
 
@@ -38,11 +44,9 @@ sub verify_server {
    my ($uri) = @_;
 
    $uri ||= $self->uri;
-   if (! defined($uri)) {
-      return $self->log->error($self->brik_help_set('uri'));
-   }
+   $self->brik_help_run_undef_arg('verify_server', $uri) or return;
 
-   my $su = Metabrik::String::Uri->new_from_brik($self) or return;
+   my $su = Metabrik::String::Uri->new_from_brik_init($self) or return;
    my $parsed = $su->parse($uri) or return;
 
    my $host = $parsed->{host};
@@ -77,9 +81,7 @@ sub getcertificate {
    my ($uri) = @_;
 
    $uri ||= $self->uri;
-   if (! defined($uri)) {
-      return $self->log->error($self->brik_help_set('uri'));
-   }
+   $self->brik_help_run_undef_arg('getcertificate', $uri) or return;
 
    if ($uri !~ /^https:\/\//) {
       return $self->log->error("must use https to get a certificate");
@@ -142,13 +144,13 @@ sub getcertificate {
    return $sock;
 }
 
-use Net::SSLeay qw/XN_FLAG_RFC2253 ASN1_STRFLGS_ESC_MSB/;
+eval("use Net::SSLeay qw/XN_FLAG_RFC2253 ASN1_STRFLGS_ESC_MSB/;");
 
 # Taken from http://cpansearch.perl.org/src/MIKEM/Net-SSLeay-1.57/examples/x509_cert_details.pl
 sub get_cert_details {
   my $x509 = shift;
   my $rv = {};
-  my $flag_rfc22536_utf8 = (XN_FLAG_RFC2253) & (~ ASN1_STRFLGS_ESC_MSB);
+  my $flag_rfc22536_utf8 = (Net::SSLeay::XN_FLAG_RFC2253()) & (~ Net::SSLeay::ASN1_STRFLGS_ESC_MSB());
 
   die 'ERROR: $x509 is NULL, gonna quit' unless $x509;
 
@@ -296,11 +298,10 @@ sub getcertificate2 {
    my $self = shift;
    my ($host, $port) = @_;
 
-   if (! defined($port)) {
-      return $self->log->error($self->brik_help_run('getcertificate2'));
-   }
+   $self->brik_help_run_undef_arg('getcertificate2', $host) or return;
+   $self->brik_help_run_undef_arg('getcertificate2', $port) or return;
 
-   use Net::SSLeay qw(print_errs set_fd);
+   eval("use Net::SSLeay qw(print_errs set_fd);");
 
    if (defined($ENV{HTTPS_PROXY})) {
       my $proxy = URI->new($ENV{HTTPS_PROXY});
@@ -476,7 +477,7 @@ Metabrik::Client::Ssl - client::ssl Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
