@@ -1,5 +1,5 @@
 #
-# $Id: Tcp.pm,v 3595633d3216 2015/10/29 21:25:42 gomor $
+# $Id: Tcp.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # client::tcp Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 3595633d3216 $',
-      tags => [ qw(unstable client tcp socket netcat) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable socket netcat) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          host => [ qw(host) ],
          port => [ qw(port) ],
@@ -68,12 +70,8 @@ sub connect {
 
    $host ||= $self->host;
    $port ||= $self->port;
-   if (! defined($host)) {
-      return $self->log->error($self->brik_help_run('connect'));
-   }
-   if (! defined($port)) {
-      return $self->log->error($self->brik_help_run('connect'));
-   }
+   $self->brik_help_run_undef_arg('connect', $host) or return;
+   $self->brik_help_run_undef_arg('connect', $port) or return;
 
    my $context = $self->context;
 
@@ -142,9 +140,7 @@ sub write {
    if (! $self->is_connected) {
       return $self->log->error($self->brik_help_run('connect'));
    }
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('write'));
-   }
+   $self->brik_help_run_undef_arg('write', $data) or return;
 
    my $socket = $self->_socket;
    $stdout ||= $socket;
@@ -378,7 +374,7 @@ Metabrik::Client::Tcp - client::tcp Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
