@@ -1,5 +1,5 @@
 #
-# $Id: Whois.pm,v 515763761308 2016/02/08 20:39:05 gomor $
+# $Id: Whois.pm,v d7acc9344973 2016/04/08 06:10:17 gomor $
 #
 # client::whois Brik
 #
@@ -11,15 +11,21 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 515763761308 $',
+      revision => '$Revision: d7acc9344973 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
+      attributes => {
+         use_normalization => [ qw(0|1) ],
+      },
+      attributes_default => {
+         use_normalization => 1,
+      },
       commands => {
          from_ip => [ qw(ip_address) ],
          from_domain => [ qw(domain) ],
          is_available_domain => [ qw(domain) ],
-         parse_raw_whois => [ qw($lines_list) ],
+         parse_raw_ip_whois => [ qw($lines_list) ],
          normalize_raw_ip_whois => [ qw($chunks $lines_list) ],
          is_ip_from_owner => [ qw(ip_address owner) ],
       },
@@ -31,11 +37,11 @@ sub brik_properties {
    };
 }
 
-sub parse_raw_whois {
+sub parse_raw_ip_whois {
    my $self = shift;
    my ($lines) = @_;
 
-   $self->brik_help_run_undef_arg('parse_raw_whois', $lines) or return;
+   $self->brik_help_run_undef_arg('parse_raw_ip_whois', $lines) or return;
 
    my $sp = Metabrik::String::Parse->new_from_brik_init($self) or return;
    my $chunks = $sp->split_by_blank_line($lines) or return;
@@ -287,12 +293,15 @@ sub from_ip {
    my $nw = Metabrik::Network::Whois->new_from_brik_init($self) or return;
    my $lines = $nw->target($ip) or return;
 
-   my $chunks = $self->parse_raw_whois($lines) or return;
-
-   my $r = $self->normalize_raw_ip_whois($chunks, $lines) or return;
+   my $r = {};
+   if ($self->use_normalization) {
+      my $chunks = $self->parse_raw_ip_whois($lines) or return;
+      $r = $self->normalize_raw_ip_whois($chunks, $lines) or return;
+   }
 
    $r->{date_queried} = localtime();
    $r->{whois_server} = $nw->last_server;
+   $r->{raw} = $lines;
 
    return $r;
 }
@@ -324,98 +333,102 @@ sub from_domain {
    my $nw = Metabrik::Network::Whois->new_from_brik_init($self) or return;
    my $lines = $nw->target($domain) or return;
 
-   my $chunks = $self->parse_raw_whois($lines);
-
    my $r = { raw => $lines };
+   $r->{date_queried} = localtime();
+   $r->{whois_server} = $nw->last_server;
 
-   # 4 categories: general, registrant, admin, tech
-   for (@$chunks) {
-      # Registrar,Sponsoring Registrar,
-      $self->_domain_lookup($_, 'registrar', 'registrar', $r);
-      $self->_domain_lookup($_, 'sponsoring_registrar', 'registrar', $r);
+   if ($self->use_normalization) {
+      my $chunks = $self->parse_raw_ip_whois($lines);
 
-      # Whois Server,
-      $self->_domain_lookup($_, 'whois_server', 'whois_server', $r);
+      # 4 categories: general, registrant, admin, tech
+      for (@$chunks) {
+         # Registrar,Sponsoring Registrar,
+         $self->_domain_lookup($_, 'registrar', 'registrar', $r);
+         $self->_domain_lookup($_, 'sponsoring_registrar', 'registrar', $r);
 
-      # Domain Name,Dominio,domain,
-      $self->_domain_lookup($_, 'domain_name', 'domain_name', $r);
-      $self->_domain_lookup($_, 'dominio', 'domain_name', $r);
-      $self->_domain_lookup($_, 'domain', 'domain_name', $r);
+         # Whois Server,
+         $self->_domain_lookup($_, 'whois_server', 'whois_server', $r);
 
-      # Creation Date,Fecha de registro,created,
-      $self->_domain_lookup($_, 'creation_date', 'creation_date', $r);
-      $self->_domain_lookup($_, 'fecha_de_registro', 'creation_date', $r);
-      $self->_domain_lookup($_, 'created', 'creation_date', $r);
+         # Domain Name,Dominio,domain,
+         $self->_domain_lookup($_, 'domain_name', 'domain_name', $r);
+         $self->_domain_lookup($_, 'dominio', 'domain_name', $r);
+         $self->_domain_lookup($_, 'domain', 'domain_name', $r);
 
-      # Updated Date,last-update,
-      $self->_domain_lookup($_, 'updated_date', 'updated_date', $r);
-      $self->_domain_lookup($_, 'last_update', 'updated_date', $r);
+         # Creation Date,Fecha de registro,created,
+         $self->_domain_lookup($_, 'creation_date', 'creation_date', $r);
+         $self->_domain_lookup($_, 'fecha_de_registro', 'creation_date', $r);
+         $self->_domain_lookup($_, 'created', 'creation_date', $r);
 
-      # Registrar Registration Expiration Date,Expiration Date,Registry Expiry Date,Fecha de vencimiento,Expiry Date,
-      $self->_domain_lookup($_, 'registrar_registration_expiration_date', 'expiration_date', $r);
-      $self->_domain_lookup($_, 'expiration_date', 'expiration_date', $r);
-      $self->_domain_lookup($_, 'registry_expiry_date', 'expiration_date', $r);
-      $self->_domain_lookup($_, 'fecha_de_vencimiento', 'expiration_date', $r);
-      $self->_domain_lookup($_, 'expiry_date', 'expiration_date', $r);
+         # Updated Date,last-update,
+         $self->_domain_lookup($_, 'updated_date', 'updated_date', $r);
+         $self->_domain_lookup($_, 'last_update', 'updated_date', $r);
 
-      # Registrar URL,Referral URL,
-      $self->_domain_lookup($_, 'registrar_url', 'registrar_url', $r);
-      $self->_domain_lookup($_, 'referral_url', 'registrar_url', $r);
+         # Registrar Registration Expiration Date,Expiration Date,Registry Expiry Date,Fecha de vencimiento,Expiry Date,
+         $self->_domain_lookup($_, 'registrar_registration_expiration_date', 'expiration_date', $r);
+         $self->_domain_lookup($_, 'expiration_date', 'expiration_date', $r);
+         $self->_domain_lookup($_, 'registry_expiry_date', 'expiration_date', $r);
+         $self->_domain_lookup($_, 'fecha_de_vencimiento', 'expiration_date', $r);
+         $self->_domain_lookup($_, 'expiry_date', 'expiration_date', $r);
 
-      # DNSSEC,
-      $self->_domain_lookup($_, 'dnssec', 'dnssec', $r);
+         # Registrar URL,Referral URL,
+         $self->_domain_lookup($_, 'registrar_url', 'registrar_url', $r);
+         $self->_domain_lookup($_, 'referral_url', 'registrar_url', $r);
 
-      # Domain Status,Status,
-      $self->_domain_lookup($_, 'domain_status', 'domain_status', $r);
-      $self->_domain_lookup($_, 'status', 'domain_status', $r);
+         # DNSSEC,
+         $self->_domain_lookup($_, 'dnssec', 'dnssec', $r);
 
-      # Name Server,nserver,
-      $self->_domain_lookup($_, 'name_server', 'name_server', $r);
-      $self->_domain_lookup($_, 'nserver', 'name_server', $r);
+         # Domain Status,Status,
+         $self->_domain_lookup($_, 'domain_status', 'domain_status', $r);
+         $self->_domain_lookup($_, 'status', 'domain_status', $r);
 
-      # Registrant Name,
-      $self->_domain_lookup($_, 'registrant_name', 'registrant_name', $r);
+         # Name Server,nserver,
+         $self->_domain_lookup($_, 'name_server', 'name_server', $r);
+         $self->_domain_lookup($_, 'nserver', 'name_server', $r);
 
-      # Registrant Organization,Organizacion,
-      $self->_domain_lookup($_, 'registrant_organization', 'registrant_organization', $r);
-      $self->_domain_lookup($_, 'organizacion', 'registrar', $r);
+         # Registrant Name,
+         $self->_domain_lookup($_, 'registrant_name', 'registrant_name', $r);
 
-      # Registrant Street,
-      $self->_domain_lookup($_, 'registrant_street', 'registrant_street', $r);
+         # Registrant Organization,Organizacion,
+         $self->_domain_lookup($_, 'registrant_organization', 'registrant_organization', $r);
+         $self->_domain_lookup($_, 'organizacion', 'registrar', $r);
 
-      # Registrant City,Ciudad,
-      $self->_domain_lookup($_, 'registrant_city', 'registrant_city', $r);
-      $self->_domain_lookup($_, 'ciudad', 'registrant_city', $r);
+         # Registrant Street,
+         $self->_domain_lookup($_, 'registrant_street', 'registrant_street', $r);
 
-      # Registrant Postal Code,
-      $self->_domain_lookup($_, 'registrant_postal_code', 'registrant_postal_code', $r);
+         # Registrant City,Ciudad,
+         $self->_domain_lookup($_, 'registrant_city', 'registrant_city', $r);
+         $self->_domain_lookup($_, 'ciudad', 'registrant_city', $r);
 
-      # Registrant State/Province,
-      $self->_domain_lookup($_, 'registrant_state_province', 'registrant_state_province', $r);
+         # Registrant Postal Code,
+         $self->_domain_lookup($_, 'registrant_postal_code', 'registrant_postal_code', $r);
 
-      # Registrant Country,Pais,
-      $self->_domain_lookup($_, 'registrant_country', 'registrant_country', $r);
-      $self->_domain_lookup($_, 'pais', 'registrant_country', $r);
+         # Registrant State/Province,
+         $self->_domain_lookup($_, 'registrant_state_province', 'registrant_state_province', $r);
 
-      # Registrant Email,
-      $self->_domain_lookup($_, 'registrant_email', 'registrant_email', $r);
-   }
+         # Registrant Country,Pais,
+         $self->_domain_lookup($_, 'registrant_country', 'registrant_country', $r);
+         $self->_domain_lookup($_, 'pais', 'registrant_country', $r);
 
-   # Dedups lines
-   for (keys %$r) {
-      next if $_ eq 'raw';
-      if (my @toks = split(/\n/, $r->{$_})) {
-         my %uniq = map { $_ => 1 } @toks;
-         $r->{$_} = join("\n", sort { $a cmp $b } keys %uniq);  # With a sort
+         # Registrant Email,
+         $self->_domain_lookup($_, 'registrant_email', 'registrant_email', $r);
       }
-   }
 
-   # If there is more than the raw key, domain exists
-   if (keys %$r > 1) {
-      $r->{domain_exists} = 1;
-   }
-   else {
-      $r->{domain_exists} = 0;
+      # Dedups lines
+      for (keys %$r) {
+         next if $_ eq 'raw';
+         if (my @toks = split(/\n/, $r->{$_})) {
+            my %uniq = map { $_ => 1 } @toks;
+            $r->{$_} = join("\n", sort { $a cmp $b } keys %uniq);  # With a sort
+         }
+      }
+
+      # If there is more than the raw key, domain exists
+      if (keys %$r > 1) {
+         $r->{domain_exists} = 1;
+      }
+      else {
+         $r->{domain_exists} = 0;
+      }
    }
 
    return $r;
