@@ -26,6 +26,7 @@ sub brik_properties {
          timeout => [ qw(0|1) ],
          rtimeout => [ qw(timeout) ],
          add_headers => [ qw(http_headers_hash) ],
+         do_eval_javascript => [ qw(0|1) ],
          _client => [ qw(object|INTERNAL) ],
          _last => [ qw(object|INTERNAL) ],
       },
@@ -35,6 +36,7 @@ sub brik_properties {
          timeout => 0,
          rtimeout => 10,
          add_headers => {},
+         do_eval_javascript => 0,
       },
       commands => {
          install => [ ], # Inherited
@@ -56,9 +58,11 @@ sub brik_properties {
          trace_redirect => [ qw(uri|OPTIONAL) ],
          screenshot => [ qw(uri output) ],
          eval_javascript => [ qw(js uri) ],
+         get_javascript => [ qw(uri) ],
          info => [ qw(uri|OPTIONAL) ],
          mirror => [ qw(url|$url_list output|OPTIONAL datadir|OPTIONAL) ],
          parse => [ qw(html) ],
+         get_last => [ ],
       },
       require_modules => {
          'Progress::Any::Output' => [ ],
@@ -70,13 +74,11 @@ sub brik_properties {
          'LWP::UserAgent::ProgressAny' => [ ],
          'HTTP::Request' => [ ],
          'WWW::Mechanize' => [ ],
+         'WWW::Mechanize::PhantomJS' => [ ],
          'Metabrik::File::Write' => [ ],
          'Metabrik::Client::Ssl' => [ ],
          'Metabrik::System::File' => [ ],
       },
-      optional_modules => {
-         'WWW::Mechanize::PhantomJS' => [ ],
-      },
       optional_binaries => {
          phantomjs => [ ],
       },
@@ -112,7 +114,18 @@ sub create_user_agent {
 
    $ENV{PERL_NET_HTTPS_SSL_SOCKET_CLASS} = 'Net::SSL';
 
-   my $mech = WWW::Mechanize->new(
+   my $mechanize = 'WWW::Mechanize';
+   if ($self->do_eval_javascript) {
+      if ($self->brik_has_module('WWW::Mechanize::PhantomJS')
+      &&  $self->brik_has_binary('phantomjs')) {
+         $mechanize = 'WWW::Mechanize::PhantomJS';
+      }
+      else {
+         return $self->log->error("create_user_agent: module [WWW::Mechanize::PhantomJS] not found, cannot do_eval_javascript");
+      }
+   }
+
+   my $mech = $mechanize->new(
       autocheck => 0,  # Do not throw on error by checking HTTP code. Let us do it.
       timeout => $self->rtimeout,
       ssl_opts => {
@@ -127,7 +140,10 @@ sub create_user_agent {
       $mech->agent($self->user_agent);
    }
    else {
-      $mech->agent_alias('Linux Mozilla');
+      # Some WWW::Mechanize::* modules can't do that
+      if ($mech->can('agent_alias')) {
+         $mech->agent_alias('Linux Mozilla');
+      }
    }
 
    $username ||= $self->username;
@@ -280,7 +296,8 @@ sub content {
       return $self->log->error("content: you have to execute a request first");
    }
 
-   return $last->decoded_content;
+   #return $last->decoded_content;
+   return $last->content;
 }
 
 sub save_content {
@@ -487,6 +504,37 @@ sub eval_javascript {
    return $self->log->error("eval_javascript: optional module [WWW::Mechanize::PhantomJS] and optional binary [phantomjs] are not available");
 }
 
+sub get_javascript {
+   my $self = shift;
+   my ($uri) = @_;
+
+   $self->brik_help_run_undef_arg('get_javascript', $uri) or return;
+
+   if ($self->brik_has_module('WWW::Mechanize::PhantomJS')
+   &&  $self->brik_has_binary('phantomjs')) {
+      my $mech = WWW::Mechanize::PhantomJS->new
+         or return $self->log->error("get_javascript: PhantomJS failed");
+
+      my $get = $mech->get($uri)
+         or return $self->log->error("get_javascript: get uri [$uri] failed");
+      if (! $get->is_success) {
+         return $self->log->error("get_javascript: error from GET: [".$get->status_line."]");
+      }
+
+      my $r = {};
+      $r->{code} = $get->code;
+      $r->{content} = $mech->decoded_content;
+
+      my $headers = $get->headers;
+      $r->{headers} = { map { $_ => $headers->{$_} } keys %$headers };
+      delete $r->{headers}->{'::std_case'};
+
+      return $r;
+   }
+
+   return $self->log->error("get_javascript: optional module [WWW::Mechanize::PhantomJS] and optional binary [phantomjs] are not available");
+}
+
 sub info {
    my $self = shift;
    my ($uri) = @_;
@@ -633,6 +681,12 @@ sub parse {
    return HTML::TreeBuilder->new_from_content($html);
 }
 
+sub get_last {
+   my $self = shift;
+
+   return $self->_last;
+}
+
 1;
 
 __END__
