@@ -1,5 +1,5 @@
 #
-# $Id: Number.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Number.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # convert::number Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
-      tags => [ qw(unstable convert number) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          to_hex => [ qw(int_number) ],
          to_int => [ qw(hex_number) ],
@@ -24,12 +26,10 @@ sub to_hex {
    my $self = shift;
    my ($int) = @_;
 
-   if (! defined($int)) {
-      return $self->log->error($self->brik_help_run('hex'));
-   }
+   $self->brik_help_run_undef_arg('to_hex', $int) or return;
 
    if ($int !~ /^[0-9]+/) {
-      return $self->log->error("hex: invalid format for int [$int]");
+      return $self->log->error("to_hex: invalid format for int [$int]");
    }
 
    return sprintf("0x%x", $int);
@@ -39,12 +39,10 @@ sub to_int {
    my $self = shift;
    my ($hex) = @_;
 
-   if (! defined($hex)) {
-      return $self->log->error($self->brik_help_run('int'));
-   }
+   $self->brik_help_run_undef_arg('to_int', $hex) or return;
 
    if ($hex !~ /^[0-9a-f]+$/i && $hex !~ /^0x[0-9a-f]+$/i) {
-      return $self->log->error("int: invalid format for hex [$hex]");
+      return $self->log->error("to_int: invalid format for hex [$hex]");
    }
 
    return sprintf("%d", hex($hex));
@@ -60,7 +58,7 @@ Metabrik::Convert::Number - convert::number Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
