@@ -1,5 +1,5 @@
 #
-# $Id: Gpg.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
+# $Id: Gpg.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # crypto::gpg Brik
 #
@@ -7,12 +7,14 @@ package Metabrik::Crypto::Gpg;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cb13feea4e0 $',
-      tags => [ qw(unstable pgp gpg gnupg) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable pgp gnupg) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          public_keyring => [ qw(file.gpg) ],
          secret_keyring => [ qw(file.gpg) ],
@@ -34,6 +36,7 @@ sub brik_properties {
          expire_key => '5y',
       },
       commands => {
+         install => [ ], # Inherited
          list_public_keys => [ ],
          list_secret_keys => [ ],
          get_public_keys => [ qw(keys_list) ],
@@ -54,7 +57,10 @@ sub brik_properties {
          'Metabrik::String::Password' => [ ],
       },
       require_binaries => {
-         'rngd' => [ ],  # apt-get install rng-tools
+         'rngd' => [ ],
+      },
+      need_packages => {
+         'ubuntu' => [ qw(rng-tools) ],
       },
    };
 }
@@ -77,14 +83,10 @@ sub generate_key {
    my $self = shift;
    my ($email, $description, $comment) = @_;
 
-   if (! defined($email)) {
-      return $self->log->error($self->brik_help_run('generate_key'));
-   }
+   $self->brik_help_run_undef_arg('generate_key', $email) or return;
 
    my $passphrase = $self->passphrase;
-   if (! defined($passphrase)) {
-      return $self->log->error($self->brik_help_set('passphrase'));
-   }
+   $self->brik_help_set_undef_arg('passphrase', $passphrase) or return;
 
    $description ||= $email;
    $comment ||= $email;
@@ -99,8 +101,8 @@ sub generate_key {
    my $filename = $sr->filename
       or return $self->log->error("generate_key: filename failed");
 
-   my $text = Metabrik::File::Text->new_from_brik($self) or return;
-   $text->output($filename);
+   my $ft = Metabrik::File::Text->new_from_brik_init($self) or return;
+   $ft->output($filename);
 
    # If key is RSA, subkey will be RSA.
    # If key is DSA, subkey will be Elgamal.
@@ -109,7 +111,7 @@ sub generate_key {
       #$subkey = 'Elgamal';
    #}
 
-   $text->write([
+   $ft->write([
       '%echo Generating a standard key', "\n",
       "Key-Type: $type_key", "\n",
       "Key-Length: $length_key", "\n",
@@ -163,9 +165,7 @@ sub delete_key {
    my $self = shift;
    my ($id) = @_;
 
-   if (! defined($id)) {
-      return $self->log->error($self->brik_help_run('delete_key'));
-   }
+   $self->brik_help_run_undef_arg('delete_key', $id) or return;
 
    my $gnupg = $self->_gnupg;
 
@@ -199,9 +199,7 @@ sub import_keys {
    my $self = shift;
    my ($file) = @_;
 
-   if (! defined($file)) {
-      return $self->log->error($self->brik_help_run('import_keys'));
-   }
+   $self->brik_help_run_undef_arg('import_keys', $file) or return;
 
    my $gnupg = $self->_gnupg;
 
@@ -272,13 +270,8 @@ sub get_public_keys {
    my $self = shift;
    my ($keys) = @_;
 
-   if (! defined($keys)) {
-      return $self->log->error($self->brik_help_run('get_public_keys'));
-   }
-
-   if (ref($keys) ne 'ARRAY') {
-      return $self->log->error("get_public_keys: argument 1 must be ARRAYREF");
-   }
+   $self->brik_help_run_undef_arg('get_public_keys', $keys) or return;
+   $self->brik_help_run_invalid_arg('get_public_keys', $keys, 'ARRAY') or return;
 
    my $gnupg = $self->_gnupg;
 
@@ -321,13 +314,8 @@ sub get_secret_keys {
    my $self = shift;
    my ($keys) = @_;
 
-   if (! defined($keys)) {
-      return $self->log->error($self->brik_help_run('get_secret_keys'));
-   }
-
-   if (ref($keys) ne 'ARRAY') {
-      return $self->log->error("get_secret_keys: argument 1 must be ARRAYREF");
-   }
+   $self->brik_help_run_undef_arg('get_secret_keys', $keys) or return;
+   $self->brik_help_run_invalid_arg('get_secret_keys', $keys, 'ARRAY') or return;
 
    my $gnupg = $self->_gnupg;
 
@@ -345,17 +333,9 @@ sub encrypt {
    my $self = shift;
    my ($data, $recipient_list) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('encrypt'));
-   }
-
-   if (! defined($recipient_list)) {
-      return $self->log->error($self->brik_help_run('encrypt'));
-   }
-
-   if (ref($recipient_list) ne 'ARRAY') {
-      return $self->log->error("encrypt: argument 2 must be ARRAYREF");
-   }
+   $self->brik_help_run_undef_arg('encrypt', $data) or return;
+   $self->brik_help_run_undef_arg('encrypt', $recipient_list) or return;
+   $self->brik_help_run_invalid_arg('encrypt', $recipient_list, 'ARRAY') or return;
 
    my @data = ();
    if (ref($data) eq 'ARRAY') {
@@ -406,13 +386,11 @@ sub decrypt {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('decrypt'));
-   }
+   $self->brik_help_run_undef_arg('decrypt', $data) or return;
 
-   my $string_password = Metabrik::String::Password->new_from_brik($self) or return;
+   my $sp = Metabrik::String::Password->new_from_brik_init($self) or return;
 
-   my $passphrase = $string_password->prompt;
+   my $passphrase = $sp->prompt;
    if (! defined($passphrase)) {
       return $self->log->error("decrypt: invalid passphrase entered");
    }
@@ -470,9 +448,7 @@ sub export_keys {
    my $self = shift;
    my ($key_id) = @_;
 
-   if (! defined($key_id)) {
-      return $self->log->error($self->brik_help_run('export_keys'));
-   }
+   $self->brik_help_run_undef_arg('export_keys', $key_id) or return;
 
    my $gnupg = $self->_gnupg;
 
@@ -514,7 +490,7 @@ Metabrik::Crypto::Gpg - crypto::gpg Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
