@@ -1,5 +1,5 @@
 #
-# $Id: Mysql.pm,v e5e3576f73a3 2015/11/10 09:17:44 gomor $
+# $Id: Mysql.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # database::mysql Brik
 #
@@ -7,12 +7,14 @@ package Metabrik::Database::Mysql;
 use strict;
 use warnings;
 
-use base qw(Metabrik::Database::Sqlite);
+use base qw(Metabrik::Database::Sqlite Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: e5e3576f73a3 $',
-      tags => [ qw(unstable database mysql) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          db => [ qw(db_name) ],
          autocommit => [ qw(0|1) ],
@@ -30,6 +32,7 @@ sub brik_properties {
          username => 'root',
       },
       commands => {
+         install => [ ], # Inherited
          open => [ qw(db_name|OPTIONAL host|OPTIONAL port|OPTIONAL username|OPTIONAL password|OPTIONAL) ],
          exec => [ qw(sql_query) ],
          create => [ qw(table_name fields_array key|OPTIONAL) ],
@@ -57,6 +60,9 @@ sub brik_properties {
          'mysql' => [ ],
          'mysqladmin' => [ ],
       },
+      need_packages => {
+         'ubuntu' => [ qw(libmysqlclient-dev mysql-client) ],
+      },
    };
 }
 
@@ -77,6 +83,10 @@ sub open {
    $port ||= $self->port;
    $username ||= $self->username;
    $password ||= $self->password || $self->password_prompt("Enter $username password: ") or return;
+   $self->brik_help_run_undef_arg('open', $db) or return;
+   $self->brik_help_run_undef_arg('open', $host) or return;
+   $self->brik_help_run_undef_arg('open', $port) or return;
+   $self->brik_help_run_undef_arg('open', $username) or return;
 
    my $dbh = DBI->connect("DBI:mysql:database=$db;host=$host;port=$port", $username, $password, {
       AutoCommit => $self->autocommit,
@@ -101,9 +111,7 @@ sub show_tables {
    my $self = shift;
 
    my $dbh = $self->dbh;
-   if (! defined($dbh)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $dbh) or return;
 
    my @tables = map { s/.*\.//; s/`//g; $_ } $dbh->tables;
 
@@ -114,9 +122,7 @@ sub createdb {
    my $self = shift;
    my ($db) = @_;
 
-   if (! defined($db)) {
-      return $self->log->error($self->brik_help_run('createdb'));
-   }
+   $self->brik_help_run_undef_arg('createdb', $db) or return;
 
    my $host = $self->host;
    my $port = $self->port;
@@ -133,9 +139,7 @@ sub dropdb {
    my $self = shift;
    my ($db) = @_;
 
-   if (! defined($db)) {
-      return $self->log->error($self->brik_help_run('dropdb'));
-   }
+   $self->brik_help_run_undef_arg('dropdb', $db) or return;
 
    my $host = $self->host;
    my $port = $self->port;
@@ -152,12 +156,8 @@ sub save {
    my $self = shift;
    my ($db, $filename) = @_;
 
-   if (! defined($db)) {
-      return $self->log->error($self->brik_help_run('save'));
-   }
-   if (! defined($filename)) {
-      return $self->log->error($self->brik_help_run('save'));
-   }
+   $self->brik_help_run_undef_arg('save', $db) or return;
+   $self->brik_help_run_undef_arg('save', $filename) or return;
 
    my $host = $self->host;
    my $port = $self->port;
@@ -174,15 +174,9 @@ sub load {
    my $self = shift;
    my ($filename, $db) = @_;
 
-   if (! defined($filename)) {
-      return $self->log->error($self->brik_help_run('load'));
-   }
-   if (! -f $filename) {
-      return $self->log->error("load: file [$filename] not found");
-   }
-   if (! defined($db)) {
-      return $self->log->error($self->brik_help_run('load'));
-   }
+   $self->brik_help_run_undef_arg('load', $filename) or return;
+   $self->brik_help_run_file_not_found('load', $filename) or return;
+   $self->brik_help_run_undef_arg('load', $db) or return;
 
    my $host = $self->host;
    my $port = $self->port;
@@ -200,9 +194,7 @@ sub create_user {
    my ($username, $password, $ip) = @_;
 
    $ip ||= '%';
-   if (! defined($username)) {
-      return $self->log->error($self->brik_help_run('create_user'));
-   }
+   $self->brik_help_run_undef_arg('create_user', $username) or return;
 
    my $mysql_host = $self->host;
    my $mysql_port = $self->port;
@@ -225,12 +217,8 @@ sub grant_all_privileges {
    my ($db, $username, $password, $ip) = @_;
 
    $ip ||= '%';
-   if (! defined($db)) {
-      return $self->log->error($self->brik_help_run('grant_all_privileges'));
-   }
-   if (! defined($username)) {
-      return $self->log->error($self->brik_help_run('grant_all_privileges'));
-   }
+   $self->brik_help_run_undef_arg('grant_all_privileges', $db) or return;
+   $self->brik_help_run_undef_arg('grant_all_privileges', $username) or return;
 
    my $mysql_host = $self->host;
    my $mysql_port = $self->port;
@@ -277,7 +265,7 @@ Metabrik::Database::Mysql - database::mysql Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
