@@ -1,5 +1,5 @@
 #
-# $Id: Ripe.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Ripe.pm,v 95cc6e668a89 2016/02/23 21:12:56 gomor $
 #
 # database::ripe Brik
 #
@@ -14,7 +14,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: 95cc6e668a89 $',
       tags => [ qw(unstable netname country as) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -42,15 +42,15 @@ sub brik_properties {
 sub update {
    my $self = shift;
 
-   # Other data than RIPE is not available anymore.
-   #ftp://ftp.afrinic.net/dbase/afrinic.db.gz
-   #ftp://ftp.apnic.net/apnic/whois-data/APNIC/split/apnic.db.inetnum.gz
-   #http://ftp.apnic.net/apnic/dbase/data/jpnic.db.gz
-   #http://ftp.apnic.net/apnic/dbase/data/krnic.db.gz
-   #http://ftp.apnic.net/apnic/dbase/data/twnic.in.gz
-   #http://ftp.apnic.net/apnic/dbase/data/twnic.pn.gz
    my @urls = qw(
+      ftp://ftp.apnic.net/apnic/whois/apnic.db.inetnum.gz
       ftp://ftp.ripe.net/ripe/dbase/ripe.db.gz
+      ftp://ftp.afrinic.net/dbase/afrinic.db.gz
+      http://ftp.apnic.net/apnic/dbase/data/jpnic.db.gz
+      http://ftp.apnic.net/apnic/dbase/data/krnic.db.gz
+      http://ftp.apnic.net/apnic/dbase/data/twnic.in.gz
+      http://ftp.apnic.net/apnic/dbase/data/twnic.pn.gz
+      ftp://ftp.arin.net/pub/rr/arin.db
    );
 
    my $datadir = $self->datadir;
@@ -74,15 +74,22 @@ sub update {
          next;
       }
 
-      $self->log->verbose("update: gunzipping file to [$unzipped]");
+      my $files = [];
+      if ($filename =~ m{.gz$}) {
+         $self->log->verbose("update: uncompressing file to [$unzipped]");
 
-      my $fc = Metabrik::File::Compress->new_from_brik_init($self) or return;
-      my $gunzip = $fc->gunzip($output, $unzipped, $datadir);
-      if (! defined($gunzip)) {
-         $self->log->warning("update: can't gunzip file [$output]");
-         next;
+         my $fc = Metabrik::File::Compress->new_from_brik_init($self) or return;
+         $files = $fc->uncompress($output, $unzipped, $datadir);
+         if (! defined($files)) {
+            $self->log->warning("update: can't uncompress file [$output]");
+            next;
+         }
       }
-      push @fetched, $unzipped;
+      else {
+         push @fetched, $output;
+      }
+
+      push @fetched, @$files;
    }
 
    return \@fetched;
@@ -110,13 +117,23 @@ sub next_record {
    if (@$lines == 0) {
       # If nothing has been read and eof reached, we return undef.
       # Otherwise, we return an empty object.
-      return $fr->eof ? undef : {};
+      if ($fr->eof) {
+         $fr->close;
+         $self->_read(undef);
+         return;
+      }
+      else {
+         return {};
+      }
    }
 
    my %record = ();
    for my $line (@$lines) {
       next if ($line =~ /^\s*#/);
 
+      $line =~ s/^\s*//;
+      $line =~ s/\s*$//;
+
       my ($key, $val);
       if ($line =~ /^(.*?)\s*:\s*(.*)$/) {
          $key = $1;
