@@ -1,5 +1,5 @@
 #
-# $Id: Vfeed.pm,v 443db6fb6411 2015/11/21 13:37:41 gomor $
+# $Id: Vfeed.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # database::vfeed Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 443db6fb6411 $',
-      tags => [ qw(unstable cve vfeed) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable cve) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          db => [ qw(vfeed.db) ],
@@ -56,9 +58,7 @@ sub cve {
    my $self = shift;
    my ($id) = @_;
 
-   if (! defined($id)) {
-      return $self->log->error($self->brik_help_run('cve'));
-   }
+   $self->brik_help_run_undef_arg('cve', $id) or return;
 
    my $db = $self->db;
    my $datadir = $self->datadir;
@@ -110,7 +110,7 @@ Metabrik::Database::Vfeed - database::vfeed Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
