@@ -1,5 +1,5 @@
 #
-# $Id: Mercurial.pm,v 2dab3f76f3fa 2016/01/18 10:59:08 gomor $
+# $Id: Mercurial.pm,v f43f03db50ed 2016/10/04 05:00:14 gomor $
 #
 # devel::mercurial Brik
 #
@@ -11,8 +11,8 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 2dab3f76f3fa $',
-      tags => [ qw(unstable) ],
+      revision => '$Revision: f43f03db50ed $',
+      tags => [ qw(unstable hg) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
@@ -56,7 +56,9 @@ sub clone {
 
    my $cmd = "hg clone $repository $directory";
 
-   return $self->execute($cmd);
+   $self->execute($cmd) or return;
+
+   return $directory;
 }
 
 sub push {
