@@ -1,5 +1,5 @@
 #
-# $Id: Mbox.pm,v 887d85a7f604 2015/11/12 14:44:58 gomor $
+# $Id: Mbox.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # email::mbox Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 887d85a7f604 $',
-      tags => [ qw(unstable email mbox) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          input => [ qw(mbox_file) ],
          _folder => [ qw(INTERNAL) ],
@@ -34,9 +36,7 @@ sub open {
    my ($input) = @_;
 
    $input ||= $self->input;
-   if (! defined($input)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $input) or return;
 
    my $folder = Email::Folder->new($input);
    if (! defined($folder)) {
@@ -50,9 +50,7 @@ sub read {
    my $self = shift;
 
    my $folder = $self->_folder;
-   if (! defined($folder)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $folder) or return;
 
    my @messages = ();
    for my $message ($folder->messages) {
@@ -69,9 +67,7 @@ sub read_next {
    my $self = shift;
 
    my $folder = $self->_folder;
-   if (! defined($folder)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $folder) or return;
 
    my $message = $folder->next_message;
 
@@ -94,7 +90,7 @@ Metabrik::Email::Mbox - email::mbox Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
