@@ -1,5 +1,5 @@
 #
-# $Id: Message.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Message.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # email::message Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
-      tags => [ qw(unstable email message) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          input => [ qw(file) ],
          output => [ qw(file) ],
@@ -38,9 +40,7 @@ sub create {
    my $self = shift;
    my ($content) = @_;
 
-   if (! defined($content)) {
-      return $self->log->error($self->brik_help_run('create'));
-   }
+   $self->brik_help_run_undef_arg('create', $content) or return;
 
    my $from = $self->from;
    my $to = $self->to;
@@ -68,7 +68,7 @@ Metabrik::Email::Message - email::message Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
