@@ -1,5 +1,5 @@
 #
-# $Id: Compress.pm,v 4d4ec604a2c0 2016/02/10 07:25:44 gomor $
+# $Id: Compress.pm,v ae4d13e0fd61 2016/04/02 12:37:00 gomor $
 #
 # file::compress brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 4d4ec604a2c0 $',
+      revision => '$Revision: ae4d13e0fd61 $',
       tags => [ qw(unstable gzip unzip gunzip uncompress) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -28,6 +28,7 @@ sub brik_properties {
          unzip => [ qw(input|OPTIONAL datadir|OPTIONAL) ],
          gunzip => [ qw(input|OPTIONAL output|OPTIONAL datadir|OPTIONAL) ],
          uncompress => [ qw(input|OPTIONAL output|OPTIONAL datadir|OPTIONAL) ],
+         gzip => [ qw(input) ],
       },
       require_modules => {
          'Compress::Zlib' => [ ],
@@ -36,9 +37,10 @@ sub brik_properties {
       },
       require_binaries => {
          unzip => [ ],
+         gzip => [ ],
       },
       need_packages => {
-         ubuntu => [ qw(unzip) ],
+         ubuntu => [ qw(unzip gzip) ],
       },
    };
 }
@@ -142,6 +144,20 @@ sub uncompress {
    return $self->log->error("uncompress: don't know how to uncompress file [$input] with MIME type [$type]");
 }
 
+sub gzip {
+   my $self = shift;
+   my ($input) = @_;
+
+   $self->brik_help_run_undef_arg('gzip', $input) or return;
+   $self->brik_help_run_file_not_found('gzip', $input) or return;
+
+   my $cmd = "gzip \"$input\"";
+
+   $self->execute($cmd) or return;
+
+   return "$input.gz";
+}
+
 1;
 
 __END__
