@@ -1,5 +1,5 @@
 #
-# $Id: Csv.pm,v be8fd29d6b2b 2016/03/21 19:51:52 gomor $
+# $Id: Csv.pm,v 1ae91f344f91 2016/04/17 14:10:32 gomor $
 #
 # file::csv Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: be8fd29d6b2b $',
+      revision => '$Revision: 1ae91f344f91 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -25,6 +25,7 @@ sub brik_properties {
          overwrite => [ qw(0|1) ],
          append => [ qw(0|1) ],
          write_header => [ qw(0|1) ],
+         use_quoting => [ qw(0|1) ],
          _csv => [ qw(INTERNAL) ],
          _fd => [ qw(INTERNAL) ],
       },
@@ -35,6 +36,7 @@ sub brik_properties {
          overwrite => 1,
          append => 0,
          write_header => 1,
+         use_quoting => 0,
       },
       commands => {
          read => [ qw(input_file|OPTIONAL) ],
@@ -177,6 +179,12 @@ sub write {
       }
 
       @fields = map { defined($_) ? $_ : 'undef' } @fields;
+      if ($self->use_quoting) {
+         for (@fields) {
+            s/"/\\"/g;
+            $_ = '"'.$_.'"';
+         }
+      }
       my $data = join($self->separator, @fields)."\n";
 
       my $r = $fw->write($data);
