@@ -1,5 +1,5 @@
 #
-# $Id: Find.pm,v dbd87bcad46e 2015/11/22 10:51:33 gomor $
+# $Id: Find.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # file::find Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: dbd87bcad46e $',
+      revision => '$Revision: 1cdea52670de $',
       tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          path => [ qw($path_list) ],
       },
@@ -35,10 +37,7 @@ sub files {
 
    $directory ||= '.';
    $filepattern ||= '.*';
-
-   if (! -d $directory) {
-      return $self->log->error("files: directory [$directory] not found");
-   }
+   $self->brik_help_run_directory_not_found('files', $directory) or return;
 
    my $file_regex = qr/$filepattern/;
    my $dot_regex = qr/^\.$/;
@@ -65,6 +64,7 @@ sub files {
    @tmp_files = map { s/^\.\///; $_ } @tmp_files;  # Remove leading dot slash
    my %uniq_files = map { $_ => 1 } @tmp_files;
    my @files = sort { $a cmp $b } keys %uniq_files;
+   @files = grep { -f $_ } @files; # Keep only files
 
    return \@files;
 }
@@ -76,18 +76,15 @@ sub all {
    my $self = shift;
    my ($dirpattern, $filepattern) = @_;
 
-   if (! defined($dirpattern) || ! defined($filepattern)) {
-      return $self->log->error($self->brik_help_run('all'));
-   }
+   my $path = $self->path;
+   $self->brik_help_run_undef_arg('all', $dirpattern) or return;
+   $self->brik_help_run_undef_arg('all', $filepattern) or return;
+   $self->brik_help_run_undef_arg('all', $path) or return;
+   $self->brik_help_run_invalid_arg('all', $path, 'ARRAY') or return;
 
    my @dirs = ();
    my @files = ();
 
-   my $path = $self->path;
-   if (ref($path) ne 'ARRAY') {
-      return $self->log->error("all: path must be an ARRAYREF");
-   }
-
    # Escape dirpattern if we are searching for a directory hierarchy
    $dirpattern =~ s/\//\\\//g;
 
@@ -137,7 +134,7 @@ Metabrik::File::Find - file::find Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
