@@ -1,5 +1,5 @@
 #
-# $Id: Ole.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Ole.pm,v 75fc1a5bf385 2016/09/28 05:57:21 gomor $
 #
 # file::ole Brik
 #
@@ -11,8 +11,8 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
-      tags => [ qw(unstable read) ],
+      revision => '$Revision: 75fc1a5bf385 $',
+      tags => [ qw(unstable read vbs) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
@@ -48,10 +48,7 @@ sub install {
    $self->SUPER::install or return;
 
    # Then Python dependant packages
-   my $prev = $self->use_sudo;
-   $self->use_sudo(1);
-   $self->system('pip install oletools --upgrade');
-   $self->use_sudo($prev);
+   $self->sudo_system('pip install oletools --upgrade');
 
    return 1;
 }
