@@ -1,5 +1,5 @@
 #
-# $Id: Read.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Read.pm,v ca350cbcb946 2016/02/14 17:58:39 gomor $
 #
 # file::read Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: ca350cbcb946 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -33,6 +33,7 @@ sub brik_properties {
       commands => {
          open => [ qw(file|OPTIONAL) ],
          close => [ ],
+         seek => [ qw(offset) ],
          read => [ ],
          read_until_blank_line => [ ],
          read_line => [ qw(count|OPTIONAL) ],
@@ -85,6 +86,22 @@ sub close {
    return 1;
 }
 
+sub seek {
+   my $self = shift;
+   my ($offset) = @_;
+
+   my $fd = $self->fd;
+   $self->brik_help_run_undef_arg('open', $fd) or return;
+   $self->brik_help_run_undef_arg('seek', $offset) or return;
+
+   my $r = CORE::seek($fd, $offset, 0);
+   if (! $r) {
+      return $self->log->error("seek: unable to seek to offset [$offset]: [$!]");
+   }
+
+   return $offset;
+}
+
 sub read {
    my $self = shift;
 
@@ -110,6 +127,9 @@ sub read {
          $out .= $_;
       }
       $self->eof(1);
+      if ($strip_crlf) {
+         $out =~ s/[\r\n]*$//;
+      }
       return $out;
    }
 
@@ -147,6 +167,9 @@ sub read_until_blank_line {
       if (eof($fd)) {
          $self->eof(1);
       }
+      if ($strip_crlf) {
+         $out =~ s/[\r\n]*$//;
+      }
       return $out;
    }
 
@@ -185,9 +208,6 @@ sub read_line {
       my $this = 1;
       while (<$fd>) {
          last if /^\s*$/;
-         if ($strip_crlf) {
-            s/[\r\n]*$//;
-         }
          $out .= $_;
          last if $this == $count;
          $count++;
@@ -195,6 +215,9 @@ sub read_line {
       if (eof($fd)) {
          $self->eof(1);
       }
+      if ($strip_crlf) {
+         $out =~ s/[\r\n]*$//;
+      }
       return $out;
    }
 
