@@ -1,5 +1,5 @@
 #
-# $Id: Type.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Type.pm,v cad2514d01b8 2016/02/20 17:35:11 gomor $
 #
 # file::type Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: cad2514d01b8 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -26,7 +26,7 @@ sub brik_properties {
          'File::LibMagic' => [ ],
       },
       need_packages => {
-         'ubuntu' => [ qw(libmagic-dev) ],
+         ubuntu => [ qw(libmagic-dev) ],
       },
    };
 }
