@@ -1,5 +1,5 @@
 #
-# $Id: Volatility.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Volatility.pm,v 249e2a3ccbd7 2016/01/09 14:52:23 gomor $
 #
 # forensic::Volatility Brik
 #
@@ -12,7 +12,7 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 # Default attribute values put here will BE inherited by subclasses
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: 249e2a3ccbd7 $',
       tags => [ qw(unstable carving carve file filecarve filecarving) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -32,6 +32,7 @@ sub brik_properties {
          command => [ qw(command file|OPTIONAL profile|OPTIONAL) ],
          envars => [ qw(file|OPTIONAL profile|OPTIONAL) ],
          pstree => [ qw(file|OPTIONAL profile|OPTIONAL) ],
+         pslist => [ qw(file|OPTIONAL profile|OPTIONAL) ],
          netscan => [ qw(file|OPTIONAL profile|OPTIONAL) ],
          hashdump => [ qw(file|OPTIONAL profile|OPTIONAL) ],
          psxview => [ qw(file|OPTIONAL profile|OPTIONAL) ],
@@ -62,7 +63,7 @@ sub imageinfo {
    $self->brik_help_run_undef_arg('imageinfo', $file) or return;
    $self->brik_help_run_file_not_found('imageinfo', $file) or return;
 
-   my $cmd = "volatility imageinfo -f $file";
+   my $cmd = "volatility imageinfo -f \"$file\"";
 
    $self->log->info("imageinfo: running...");
    my $data = $self->capture($cmd);
@@ -92,7 +93,7 @@ sub command {
    $self->brik_help_run_undef_arg('command', $file) or return;
    $self->brik_help_run_undef_arg('command', $profile) or return;
 
-   my $cmd = "volatility --profile $profile $command -f $file";
+   my $cmd = "volatility --profile $profile $command -f \"$file\"";
 
    return $self->execute($cmd);
 }
@@ -125,6 +126,20 @@ sub pstree {
    return $self->execute($cmd);
 }
 
+sub pslist {
+   my $self = shift;
+   my ($file, $profile) = @_;
+
+   $file ||= $self->input;
+   $profile ||= $self->profile;
+   $self->brik_help_run_undef_arg('pslist', $file) or return;
+   $self->brik_help_run_undef_arg('pslist', $profile) or return;
+
+   my $cmd = "volatility --profile $profile pslist -v -f $file";
+
+   return $self->execute($cmd);
+}
+
 sub netscan {
    my $self = shift;
    my ($file, $profile) = @_;
