@@ -1,5 +1,5 @@
 #
-# $Id: Fan.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Fan.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # harware::fan Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::File::Text);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
-      tags => [ qw(unstable hardware fan) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          info => [ ],
          #status => [ ],
@@ -26,13 +28,9 @@ sub info {
    my $self = shift;
 
    my $base_file = '/proc/acpi/ibm/fan';
+   $self->brik_help_run_file_not_found('info', $base_file) or return;
 
-   if (! -f $base_file) {
-      return $self->log->error("info: cannot find file [$base_file]");
-   }
-
-   my $data = $self->read($base_file)
-      or return $self->log->error("info: read failed");
+   my $data = $self->read($base_file) or return;
    chomp($data);
 
    my $info_hash = {};
@@ -62,7 +60,7 @@ Metabrik::Hardware::Fan - hardware::fan Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
