@@ -1,5 +1,5 @@
 #
-# $Id: Jpg.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Jpg.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # image::jpg Brik
 #
@@ -7,17 +7,23 @@ package Metabrik::Image::Jpg;
 use strict;
 use warnings;
 
-use base qw(Metabrik::Shell::Command);
+use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
-      tags => [ qw(unstable image jpg jpeg) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable jpeg) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
+         install => [ ], # Inherited
          info => [ qw(image.jpg) ],
       },
       require_binaries => {
-         'jhead' => [ ],  # apt-get install jhead
+         'jhead' => [ ],
+      },
+      need_packages => {
+         'ubuntu' => [ qw(jhead) ],
       },
    };
 }
@@ -26,12 +32,11 @@ sub info {
    my $self = shift;
    my ($image) = @_;
 
-   if (! defined($image)) {
-      return $self->log->error($self->brik_help_run('info'));
-   }
+   $self->brik_help_run_undef_arg('info', $image) or return;
+   $self->brik_help_run_file_not_found('info', $image) or return;
 
    my $cmd = "jhead \"$image\"";
-   my $out = $self->capture($cmd);
+   my $out = $self->capture($cmd) or return;
 
    my $info = {};
    for my $this (@$out) {
@@ -55,7 +60,7 @@ Metabrik::Image::Jpg - image::jpg Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
