@@ -1,5 +1,5 @@
 #
-# $Id: Ethernet.pm,v e9efd64d88ce 2015/02/26 06:10:35 gomor $
+# $Id: Ethernet.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # lookup::ethernet Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: e9efd64d88ce $',
-      tags => [ qw(unstable lookup ethernet) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          from_dec => [ qw(dec_number) ],
          from_hex => [ qw(hex_number) ],
@@ -62,9 +64,7 @@ sub from_hex {
    my $self = shift;
    my ($hex) = @_;
 
-   if (! defined($hex)) {
-      return $self->log->error($self->brik_help_run('from_hex'));
-   }
+   $self->brik_help_run_undef_arg('from_hex', $hex) or return;
 
    $hex =~ s/^0x//;
    if ($hex !~ /^[0-9a-f]+$/i) {
@@ -72,16 +72,14 @@ sub from_hex {
    }
    $hex = sprintf("0x%04s", $hex);
 
-   return $self->_lookup->{$hex} || 'unknown';
+   return $self->_lookup->{$hex} || 'undef';
 }
 
 sub from_dec {
    my $self = shift;
    my ($dec) = @_;
 
-   if (! defined($dec)) {
-      return $self->log->error($self->brik_help_run('from_dec'));
-   }
+   $self->brik_help_run_undef_arg('from_dec', $dec) or return;
 
    if ($dec !~ /^[0-9]+$/) {
       return $self->log->error("from_dec: invalid format for dec [$dec]");
@@ -95,9 +93,7 @@ sub from_string {
    my $self = shift;
    my ($string) = @_;
 
-   if (! defined($string)) {
-      return $self->log->error($self->brik_help_run('from_string'));
-   }
+   $self->brik_help_run_undef_arg('from_string', $string) or return;
 
    my $lookup = $self->_lookup;
 
@@ -106,7 +102,7 @@ sub from_string {
       $rev->{$val} = $key;
    }
 
-   return $rev->{$string} || 'unknown';
+   return $rev->{$string} || 'undef';
 }
 
 1;
@@ -119,7 +115,7 @@ Metabrik::Lookup::Ethernet - lookup::ethernet Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
