@@ -1,5 +1,5 @@
 #
-# $Id: Oui.pm,v 4f8333db5069 2015/11/19 07:36:05 gomor $
+# $Id: Oui.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # lookup::oui Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::File::Text);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 4f8333db5069 $',
-      tags => [ qw(unstable lookup oui ieee) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable ieee) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          input => [ qw(input) ],
@@ -58,14 +60,11 @@ sub load {
    my ($input) = @_;
 
    $input ||= $self->datadir.'/'.$self->input;
-   if (! -f $input) {
-      return $self->log->error("load: file [$input] not found");
-   }
+   $self->brik_help_run_file_not_found('load', $input) or return;
 
    $self->as_array(1);
 
-   my $data = $self->read($input)
-      or return $self->log->error("load: read failed");
+   my $data = $self->read($input) or return;
 
    return $self->_load($data);
 }
@@ -74,9 +73,7 @@ sub from_hex {
    my $self = shift;
    my ($hex) = @_;
 
-   if (! defined($hex)) {
-      return $self->log->error($self->brik_help_run('from_hex'));
-   }
+   $self->brik_help_run_undef_arg('from_hex', $hex) or return;
 
    my $data = $self->_load || $self->load;
    if (! defined($data)) {
@@ -115,9 +112,7 @@ sub from_string {
    my $self = shift;
    my ($string) = @_;
 
-   if (! defined($string)) {
-      return $self->log->error($self->brik_help_run('from_string'));
-   }
+   $self->brik_help_run_undef_arg('from_string', $string) or return;
 
    my $data = $self->_load || $self->load;
    if (! defined($data)) {
@@ -147,7 +142,7 @@ sub all {
 
    my $data = $self->_load || $self->load;
    if (! defined($data)) {
-      return $self->log->error("from_string: load failed");
+      return $self->log->error("all: load failed");
    }
 
    my %result = ();
@@ -174,7 +169,7 @@ Metabrik::Lookup::Oui - lookup::oui Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
