@@ -1,5 +1,5 @@
 #
-# $Id: Service.pm,v 4f8333db5069 2015/11/19 07:36:05 gomor $
+# $Id: Service.pm,v 6391b00ed43b 2016/01/26 20:00:14 gomor $
 #
 # lookup::service Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::File::Csv);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 4f8333db5069 $',
-      tags => [ qw(unstable lookup service iana) ],
+      revision => '$Revision: 6391b00ed43b $',
+      tags => [ qw(unstable iana) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          input => [ qw(input) ],
@@ -68,10 +70,10 @@ sub update {
          s/\n/ /g;
       }
 
-      $ft->write(\@new, $output);
+      $ft->write(\@new, $datadir.'/'.$output);
    }
 
-   return $output;
+   return $datadir.'/'.$output;
 }
 
 sub load {
@@ -79,12 +81,9 @@ sub load {
    my ($input) = @_;
 
    $input ||= $self->datadir.'/'.$self->input;
-   if (! -f $input) {
-      return $self->log->error("load: file [$input] not found");
-   }
+   $self->brik_help_run_file_not_found('load', $input) or return;
 
-   my $data = $self->read($input)
-      or return $self->log->error("load: read failed");
+   my $data = $self->read($input) or return;
 
    return $self->_load($data);
 }
@@ -93,9 +92,7 @@ sub from_dec {
    my $self = shift;
    my ($dec) = @_;
 
-   if (! defined($dec)) {
-      return $self->log->error($self->brik_help_run('from_dec'));
-   }
+   $self->brik_help_run_undef_arg('from_dec', $dec) or return;
 
    my $data = $self->_load || $self->load;
    if (! defined($data)) {
@@ -109,16 +106,14 @@ sub from_dec {
    }
 
    # No match
-   return 'unknown';
+   return 'undef';
 }
 
 sub from_hex {
    my $self = shift;
    my ($hex) = @_;
 
-   if (! defined($hex)) {
-      return $self->log->error($self->brik_help_run('from_hex'));
-   }
+   $self->brik_help_run_undef_arg('from_hex', $hex) or return;
 
    my $dec = hex($hex);
 
@@ -129,9 +124,7 @@ sub from_string {
    my $self = shift;
    my ($string) = @_;
 
-   if (! defined($string)) {
-      return $self->log->error($self->brik_help_run('from_string'));
-   }
+   $self->brik_help_run_undef_arg('from_string', $string) or return;
 
    my $data = $self->_load || $self->load;
    if (! defined($data)) {
@@ -161,7 +154,7 @@ Metabrik::Lookup::Service - lookup::service Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
