@@ -1,5 +1,5 @@
 #
-# $Id: Arp.pm,v 677135422623 2016/01/29 18:14:57 gomor $
+# $Id: Arp.pm,v 7d4af34f011c 2016/04/12 05:55:37 gomor $
 #
 # network::arp Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Network::Frame Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 677135422623 $',
+      revision => '$Revision: 7d4af34f011c $',
       tags => [ qw(unstable cache poison eui64 discover scan eui-64) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -50,10 +50,11 @@ sub brik_properties {
          'Metabrik::System::Process' => [ ],
       },
       optional_binaries => {
-         'arpspoof' => [ ],
+         arpspoof => [ ],
       },
       need_packages => {
-         'ubuntu' => [ qw(dsniff libnet-libdnet-perl) ],
+         ubuntu => [ qw(dsniff libnet-libdnet-perl) ],
+         freebsd => [ qw(libdnet) ],
       },
    };
 }
