@@ -1,5 +1,5 @@
 #
-# $Id: Device.pm,v 443db6fb6411 2015/11/21 13:37:41 gomor $
+# $Id: Device.pm,v 24e7f3ac4f83 2016/02/05 06:53:19 gomor $
 #
 # network::device Brik
 #
@@ -7,24 +7,30 @@ package Metabrik::Network::Device;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 443db6fb6411 $',
-      tags => [ qw(unstable network device interface) ],
+      revision => '$Revision: 24e7f3ac4f83 $',
+      tags => [ qw(unstable interface) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
-         'enable_warnings' => [ qw(0|1) ],
+         device => [ qw(device) ],
+         enable_warnings => [ qw(0|1) ],
       },
       attributes_default => {
-         'enable_warnings' => 0,
+         enable_warnings => 0,
       },
       commands => {
+         install => [ ], # Inherited
          list => [ ],
-         get => [ qw(device) ],
+         get => [ qw(device|OPTIONAL) ],
          default => [ qw(destination_ip|OPTIONAL) ],
          show => [ qw(device_array|OPTIONAL) ],
          internet_address => [ ],
+         my_ipv4 => [ qw(device|OPTIONAL) ],
+         my_ipv6 => [ qw(device|OPTIONAL) ],
       },
       require_modules => {
          'Net::Libdnet::Intf' => [ ],
@@ -33,6 +39,20 @@ sub brik_properties {
          'Net::IPv4Addr' => [ ],
          'Metabrik::Client::Www' => [ ],
       },
+      need_packages => {
+         ubuntu => [ qw(libpcap-dev libnet-libdnet-perl) ],
+         freebsd => [ qw(p5-Net-Pcap libdnet) ],
+      },
+   };
+}
+
+sub brik_use_properties {
+   my $self = shift;
+
+   return {
+      attributes_default => {
+         device => $self->global->device,
+      },
    };
 }
 
@@ -56,9 +76,8 @@ sub get {
    my $self = shift;
    my ($device) = @_;
 
-   if (! defined($device)) {
-      return $self->log->error($self->brik_help_run('get'));
-   }
+   $device ||= $self->device;
+   $self->brik_help_run_undef_arg('get', $device) or return;
 
    my $intf = Net::Libdnet::Intf->new;
    if (! defined($intf)) {
@@ -153,10 +172,7 @@ sub show {
    my $self = shift;
    my ($devices) = @_;
 
-   $devices ||= $self->list;
-   if (! defined($devices)) {
-      return $self->log->error("show: list failed");
-   } 
+   $devices ||= $self->list or return;
 
    for my $this (@$devices) {
       $self->debug && $self->log->debug("show: found device [$this]");
@@ -168,9 +184,9 @@ sub show {
       }
 
       printf("device: %s\nipv4: %s  subnet4: %s\nipv6: %s  subnet6: %s\n\n",
-         $device->{device},
-         $device->{ipv4},
-         $device->{subnet4},
+         $device->{device} || 'undef',
+         $device->{ipv4} || 'undef',
+         $device->{subnet4} || 'undef',
          $device->{ipv6} || 'undef',
          $device->{subnet6} || 'undef'
       );
@@ -186,14 +202,47 @@ sub internet_address {
 
    #my $url = 'http://ip.nu';
    my $url = 'http://www.whatsmyip.net/';
-   my $get = $cw->get($url)
-      or return $self->log->error("internet_address: get failed");
+   my $get = $cw->get($url) or return;
 
    my $html = $get->{content};
 
    my ($ip) = $html =~ /(\d+\.\d+\.\d+\.\d+)/;
 
-   return $ip || undef;
+   return $ip || 'undef';
+}
+
+sub my_ipv4 {
+   my $self = shift;
+   my ($device) = @_;
+
+   $device ||= $self->device;
+   $self->brik_help_run_undef_arg('my_ipv4', $device) or return;
+
+   my $get = $self->get($device) or return;
+
+   my $ip = $get->{ipv4};
+   if (! defined($ip)) {
+      return $self->log->error("my_ipv4: IPv4 address not found for device [$device]");
+   }
+
+   return $ip;
+}
+
+sub my_ipv6 {
+   my $self = shift;
+   my ($device) = @_;
+
+   $device ||= $self->device;
+   $self->brik_help_run_undef_arg('my_ipv6', $device) or return;
+
+   my $get = $self->get($device) or return;
+
+   my $ip = $get->{ipv6};
+   if (! defined($ip)) {
+      return $self->log->error("my_ipv6: IPv6 address not found for device [$device]");
+   }
+
+   return $ip;
 }
 
 1;
@@ -206,7 +255,7 @@ Metabrik::Network::Device - network::device Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
