@@ -1,5 +1,5 @@
 #
-# $Id: Ftp.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Ftp.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::ftp Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
-      tags => [ qw(unstable network ftp) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          hostname => [ qw(hostname) ],
          port => [ qw(port) ],
@@ -24,7 +26,7 @@ sub brik_properties {
       attributes_default => {
          port => 21,
          username => 'anonymous',
-         password => 'nop@no.fr',
+         password => 'nop@metabrik.org',
          recurse => 0,
       },
       commands => {
@@ -37,7 +39,7 @@ sub brik_properties {
          ascii => [ ],
          rmdir => [ qw(directory) ],
          mkdir => [ qw(directory) ],
-         get => [ qw(remote_file local_file|OPTIONAL) ],
+         get => [ qw(remote_file local_file) ],
          close => [ ],
       },
       require_modules => {
@@ -50,9 +52,7 @@ sub open {
    my $self = shift;
 
    my $hostname = $self->hostname;
-   if (! defined($hostname)) {
-      return $self->log->error($self->brik_help_set('hostname'));
-   }
+   $self->brik_help_run_undef_arg('open', $hostname) or return;
 
    my $port = $self->port;
    my $username = $self->username;
@@ -75,11 +75,8 @@ sub cwd {
    my ($directory) = @_;
 
    $directory ||= '';
-
    my $ftp = $self->_ftp;
-   if (! defined($ftp)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $ftp) or return;
 
    my $r = $ftp->cwd($directory);
 
@@ -90,9 +87,7 @@ sub pwd {
    my $self = shift;
 
    my $ftp = $self->_ftp;
-   if (! defined($ftp)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $ftp) or return;
 
    my $r = $ftp->pwd;
 
@@ -104,9 +99,7 @@ sub ls {
    my ($directory) = @_;
 
    my $ftp = $self->_ftp;
-   if (! defined($ftp)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $ftp) or return;
 
    $directory ||= $ftp->pwd;
 
@@ -120,9 +113,7 @@ sub dir {
    my ($directory) = @_;
 
    my $ftp = $self->_ftp;
-   if (! defined($ftp)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $ftp) or return;
 
    $directory ||= $ftp->pwd;
 
@@ -135,14 +126,9 @@ sub rmdir {
    my $self = shift;
    my ($directory) = @_;
 
-   if (! defined($directory)) {
-      return $self->log->error($self->brik_help_run('rmdir'));
-   }
-
    my $ftp = $self->_ftp;
-   if (! defined($ftp)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $ftp) or return;
+   $self->brik_help_run_undef_arg('rmdir', $directory) or return;
 
    my $r = $ftp->rmdir($directory, $self->recurse);
 
@@ -153,14 +139,9 @@ sub mkdir {
    my $self = shift;
    my ($directory) = @_;
 
-   if (! defined($directory)) {
-      return $self->log->error($self->brik_help_run('mkdir'));
-   }
-
    my $ftp = $self->_ftp;
-   if (! defined($ftp)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $ftp) or return;
+   $self->brik_help_run_undef_arg('mkdir', $directory) or return;
 
    my $r = $ftp->mkdir($directory, $self->recurse);
 
@@ -171,9 +152,7 @@ sub binary {
    my $self = shift;
 
    my $ftp = $self->_ftp;
-   if (! defined($ftp)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $ftp) or return;
 
    my $r = $ftp->binary;
 
@@ -184,9 +163,7 @@ sub ascii {
    my $self = shift;
 
    my $ftp = $self->_ftp;
-   if (! defined($ftp)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $ftp) or return;
 
    my $r = $ftp->ascii;
 
@@ -198,15 +175,9 @@ sub get {
    my ($remote, $local) = @_;
 
    my $ftp = $self->_ftp;
-   if (! defined($ftp)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
-
-   if (! defined($remote)) {
-      return $self->log->error($self->brik_help_run('get'));
-   }
-
-   $local ||= $self->global->output;
+   $self->brik_help_run_undef_arg('open', $ftp) or return;
+   $self->brik_help_run_undef_arg('get', $remote) or return;
+   $self->brik_help_run_undef_arg('get', $local) or return;
 
    my $r = $ftp->get($remote, $local);
 
@@ -234,7 +205,7 @@ Metabrik::Network::Ftp - network::ftp Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
