@@ -1,5 +1,5 @@
 #
-# $Id: Http.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
+# $Id: Http.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::http Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::Client::Tcp);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cb13feea4e0 $',
-      tags => [ qw(unstable http) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          host_header => [ qw(host_header) ],
       },
@@ -31,10 +33,7 @@ sub probe {
 
    $host ||= $self->host;
    $port ||= 80;
-
-   if (! defined($host)) {
-      return $self->log->error($self->brik_help_run('probe'));
-   }
+   $self->brik_help_run_undef_arg('probe', $host) or return;
 
    my $probe = "GET / HTTP/1.0\r\n\r\n";
    if ($self->host_header) {
@@ -43,14 +42,14 @@ sub probe {
 
    $self->host($host);
    $self->port($port);
-   $self->connect or return $self->log->error("probe: connect failed");
-   $self->write($probe) or return $self->log->error("probe: write failed");
-   my $response = $self->read or return $self->log->error("probe: read failed");
+   $self->connect or return;
+   $self->write($probe) or return;
+   my $response = $self->read or return;
    $self->disconnect;
 
    if (length($response)) {
-      my $parse = Metabrik::String::Parse->new_from_brik_init($self) or return;
-      return $parse->to_array($response);
+      my $sp = Metabrik::String::Parse->new_from_brik_init($self) or return;
+      return $sp->to_array($response);
    }
 
    return $response;
@@ -66,7 +65,7 @@ Metabrik::Network::Http - network::http Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
