@@ -1,5 +1,5 @@
 #
-# $Id: Netbios.pm,v 1f774a18593c 2015/02/08 16:21:47 gomor $
+# $Id: Netbios.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::netbios Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1f774a18593c $',
-      tags => [ qw(unstable netbios) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          probe => [ qw(ipv4_address) ],
       },
@@ -26,9 +28,7 @@ sub probe {
    my $self = shift;
    my ($ip) = @_;
 
-   if (! defined($ip)) {
-      return $self->log->error($self->brik_help_run('probe'));
-   }
+   $self->brik_help_run_undef_arg('probe', $ip) or return;
 
    my $nb = Net::NBName->new;
    if (! $nb) {
@@ -74,7 +74,7 @@ Metabrik::Network::Netbios - network::netbios Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
