@@ -1,5 +1,5 @@
 #
-# $Id: Nikto.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
+# $Id: Nikto.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::nikto Brik
 #
@@ -7,12 +7,14 @@ package Metabrik::Network::Nikto;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cb13feea4e0 $',
-      tags => [ qw(unstable network security scanner nikto) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable security scanner vulnerability vuln scan) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          uri => [ qw(uri) ],
@@ -25,8 +27,18 @@ sub brik_properties {
          output => 'last.html',
       },
       commands => {
+         install => [ ], # Inherited
          start => [ qw(uri|OPTIONAL) ],
       },
+      require_modules => {
+         'Metabrik::String::Uri' => [ ],
+      },
+      require_binaries => {
+         'nikto' => [ ],
+      },
+      need_packages => {
+         'ubuntu' => [ qw(nikto) ],
+      },
    };
 }
 
@@ -53,17 +65,15 @@ sub start {
 
    $output ||= $self->output;
    $uri ||= $self->uri;
-   if (! defined($uri)) {
-      return $self->log->error($self->brik_help_set('uri'));
-   }
+   $self->brik_help_run_undef_arg('start', $uri) or return;
 
-   my $target = Metabrik::String::Uri->new_from_brik($self) or return;
-   my $p = $target->parse($uri);
+   my $su = Metabrik::String::Uri->new_from_brik_init($self) or return;
+   my $p = $su->parse($uri) or return;
 
    my $host = $p->{host};
    my $port = $p->{port};
    my $path = $p->{path};
-   my $use_ssl = $target->is_https_scheme($p);
+   my $use_ssl = $su->is_https_scheme($p);
 
    my $args = $self->args;
 
@@ -93,7 +103,7 @@ Metabrik::Network::Nikto - network::nikto Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
