@@ -1,5 +1,5 @@
 #
-# $Id: Nmap.pm,v 14a5b315905e 2015/01/08 07:00:53 gomor $
+# $Id: Nmap.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::nmap Brik
 #
@@ -7,12 +7,14 @@ package Metabrik::Network::Nmap;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 14a5b315905e $',
-      tags => [ qw(unstable network security scanner nmap) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable security scan vulnerability vuln port portscan synscan syn udpscan scanner nmap) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          targets => [ qw(nmap_targets) ],
@@ -33,6 +35,7 @@ sub brik_properties {
          save_output => 0,
       },
       commands => {
+         install => [ ], # Inherited
          tcp_syn => [ ],
          tcp_connect => [ ],
          udp => [ ],
@@ -41,6 +44,9 @@ sub brik_properties {
          'sudo' => [ ],
          'nmap' => [ ],
       },
+      need_packages => {
+         'ubuntu' => [ qw(nmap) ],
+      },
    };
 }
 
@@ -184,7 +190,7 @@ Metabrik::Network::Nmap - network::nmap Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
