@@ -1,5 +1,5 @@
 #
-# $Id: Read.pm,v 4a548f1412b7 2015/11/22 16:44:04 gomor $
+# $Id: Read.pm,v 677135422623 2016/01/29 18:14:57 gomor $
 #
 # network::read Brik
 #
@@ -7,12 +7,14 @@ package Metabrik::Network::Read;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::Network::Frame);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 4a548f1412b7 $',
-      tags => [ qw(unstable network read ethernet ip raw socket) ],
+      revision => '$Revision: 677135422623 $',
+      tags => [ qw(unstable ethernet ip raw socket) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          device => [ qw(device) ],
          rtimeout => [ qw(seconds) ],
@@ -20,12 +22,12 @@ sub brik_properties {
          protocol => [ qw(tcp|udp) ],
          layer => [ qw(2|3|4) ],
          filter => [ qw(pcap_filter) ],
-         max_read => [ qw(integer_packet_count) ],
+         count => [ qw(count) ],
          _dump => [ qw(INTERNAL) ],
       },
       attributes_default => {
          layer => 2,
-         max_read => 0,
+         count => 0,
          family => 'ipv4',
          protocol => 'tcp',
          rtimeout => 5,
@@ -33,12 +35,14 @@ sub brik_properties {
       },
       commands => {
          open => [ qw(layer|OPTIONAL device|OPTIONAL filter|OPTIONAL) ],
-         read_next => [ ],
-         read_until_timeout => [ ],
+         read => [ ],
+         read_next => [ qw(count) ],
+         read_until_timeout => [ qw(count timeout|OPTIONAL) ],
          close => [ ],
          has_timeout => [ ],
          reset_timeout => [ ],
          reply => [ qw(frame) ],
+         to_simple => [ qw(frame|$frame_list) ],
       },
       require_modules => {
          'Net::Frame::Dump' => [ ],
@@ -61,9 +65,7 @@ sub open {
    my $self = shift;
    my ($layer, $device, $filter) = @_;
 
-   if ($< != 0) {
-      return $self->log->error("open: must be root to run");
-   }
+   $self->brik_help_run_must_be_root('open') or return;
 
    $layer ||= 2;
    $device ||= $self->device;
@@ -82,7 +84,7 @@ sub open {
          dev => $device,
          timeoutOnNext => $self->rtimeout,
          filter => $filter,
-      );
+      ) or return $self->log->error("open: Net::Frame::Dump::Online2->new failed");
    }
    elsif ($self->layer != 3) {
       return $self->log->error("open: not implemented");
@@ -93,45 +95,89 @@ sub open {
    return $self->_dump($dump);
 }
 
-sub read_next {
+sub read {
    my $self = shift;
 
    my $dump = $self->_dump;
-   if (! defined($dump)) {
-      return $self->log->error($self->brik_help_run('open'));
+   $self->brik_help_run_undef_arg('open', $dump) or return;
+
+   my @next = ();
+   my $count = 0;
+   while (my $next = $dump->next) {
+      $self->log->verbose("read: read ".++$count." packet(s)");
+      if (ref($next) eq 'ARRAY') {
+         push @next, @$next;
+      }
+      else {
+         push @next, $next;
+      }
    }
 
-   my $next = $dump->next;
+   return \@next;
+}
 
-   return defined($next) ? $next : 0;
+sub read_next {
+   my $self = shift;
+   my ($count) = @_;
+
+   $count ||= $self->count;
+   my $dump = $self->_dump;
+   $self->brik_help_run_undef_arg('open', $dump) or return;
+
+   my @next = ();
+   my $read_count = 0;
+   while (1) {
+      my $next = $dump->next;
+      if (defined($next)) {
+         $read_count++;
+         push @next, $next;
+         $self->debug && $self->log->debug("read_next: read $read_count packet(s)");
+         last if $read_count >= $count;
+      }
+   }
+
+   return \@next;
 }
 
 sub read_until_timeout {
    my $self = shift;
+   my ($count, $rtimeout) = @_;
 
+   $count ||= $self->count;
+   $rtimeout ||= $self->rtimeout;
    my $dump = $self->_dump;
-   if (! defined($dump)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $dump) or return;
 
-   my $rtimeout = $self->rtimeout;
-   my $max_read = $self->max_read;
-   $self->log->verbose("next_until_timeout: will read until $rtimeout seconds timeout or $max_read max read packet(s) has been read");
+   my $prev = $dump->timeoutOnNext;
+   $dump->timeoutOnNext($rtimeout);
 
-   my $count = 0;
+   $self->debug && $self->log->debug("next_until_timeout: will read until [$rtimeout] ".
+      "seconds or [$count] packet(s) have been read");
+
+   my $read_count = 0;
    my @next = ();
    while (! $dump->timeout) {
-      if ($max_read && $count == $max_read) {
+      if ($count && $read_count >= $count) {
          last;
       }
-
+ 
       if (my $next = $dump->next) {
          push @next, $next;
-         $self->debug && $self->log->debug("next_until_timeout: read one packet");
-         $count++;
+         $read_count++;
       }
    }
 
+   if ($self->debug) {
+      if ($dump->timeout) {
+         $self->log->debug("next_until_timeout: timeout reached after [$rtimeout]");
+      }
+      else {
+         $self->log->debug("next_until_timeout: packet count reached after [$read_count]");
+      }
+   }
+
+   $dump->timeoutOnNext($prev);
+
    return \@next;
 }
 
@@ -139,18 +185,10 @@ sub reply {
    my $self = shift;
    my ($frame) = @_;
 
-   if (! defined($frame)) {
-      return $self->log->error($self->brik_help_run('reply'));
-   }
-
-   if (ref($frame) ne 'Net::Frame::Simple') {
-      return $self->log->error("reply: frame must be Net::Frame::Simple object");
-   }
-
    my $dump = $self->_dump;
-   if (! defined($dump)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $dump) or return;
+   $self->brik_help_run_undef_arg('reply', $frame) or return;
+   $self->brik_help_run_invalid_arg('reply', $frame, 'Net::Frame::Simple') or return;
 
    return $dump->getFramesFor($frame);
 }
@@ -197,6 +235,20 @@ sub close {
    return 1;
 }
 
+sub to_simple {
+   my $self = shift;
+   my ($frames) = @_;
+
+   $self->brik_help_run_undef_arg('to_simple', $frames) or return;
+   my $ref = $self->brik_help_run_invalid_arg('to_simple', $frames, 'ARRAY', 'SCALAR')
+      or return;
+   if ($ref eq 'ARRAY') {
+      $self->brik_help_run_empty_array_arg('to_simple', $frames) or return;
+   }
+
+   return $self->from_read($frames);
+}
+
 1;
 
 __END__
@@ -207,7 +259,7 @@ Metabrik::Network::Read - network::read Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
