@@ -1,5 +1,5 @@
 #
-# $Id: Arpdiscover.pm,v d0af4137e22a 2015/10/29 21:23:12 gomor $
+# $Id: Arpdiscover.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::sinfp3::arpdiscover Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: d0af4137e22a $',
-      tags => [ qw(unstable network sinfp3 sinfp arpdiscover arp arpscan ipv6) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable network sinfp scan arp arpscan ipv6) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          subnet => [ qw(target_subnet) ],
          use_ipv6 => [ qw(0|1) ],
@@ -101,7 +103,7 @@ Metabrik::Network::Sinfp3::Arpdiscover - network::sinfp3::arpdiscover Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
