@@ -1,5 +1,5 @@
 #
-# $Id: Sqlmap.pm,v 14a5b315905e 2015/01/08 07:00:53 gomor $
+# $Id: Sqlmap.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::sqlmap Brik
 #
@@ -7,19 +7,21 @@ package Metabrik::Network::Sqlmap;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 14a5b315905e $',
-      tags => [ qw(unstable network security scanner sqlmap sql injection) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable security scan vulnerability vuln scanner sql injection blind) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          cookie => [ qw(string) ],
          parameter => [ qw(parameter_name) ],
          request_file => [ qw(file) ],
          args => [ qw(sqlmap_arguments) ],
-         output_file => [ qw(file) ],
+         output => [ qw(file) ],
       },
       attributes_default => {
          request_file => 'sqlmap_request.txt',
@@ -27,8 +29,12 @@ sub brik_properties {
          args => '--ignore-proxy -v 3 --level=5 --risk=3 --user-agent "Mozilla"',
       },
       commands => {
+         install => [ ], # Inherited
          start => [ ],
       },
+      need_packages => {
+         'ubuntu' => [ qw(python python-pip) ],
+      },
    };
 }
 
@@ -41,15 +47,13 @@ sub start {
    my $cookie = $self->cookie;
    my $parameter = $self->parameter;
    my $request_file = $datadir.'/'.$self->request_file;
-   my $output_file = $datadir.'/'.$self->output_file;
+   my $output = $datadir.'/'.$self->output;
 
-   if (! -f $request_file) {
-      return $self->log->error("start: request file [$request_file] not found");
-   }
+   $self->brik_help_run_file_not_found('start', $request_file) or return;
 
    my $cmd = "sqlmap -p $parameter $args -r $request_file";
-   if (defined($output_file)) {
-      $cmd .= ' 2>&1 | tee '.$output_file;
+   if (defined($output)) {
+      $cmd .= ' 2>&1 | tee '.$output;
    }
 
    system($cmd);
@@ -67,7 +71,7 @@ Metabrik::Network::Sqlmap - network::sqlmap Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
