@@ -1,5 +1,5 @@
 #
-# $Id: Traceroute.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Traceroute.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::traceroute Brik
 #
@@ -7,13 +7,15 @@ package Metabrik::Network::Traceroute;
 use strict;
 use warnings;
 
-use base qw(Metabrik::Shell::Command);
+use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 # Default attribute values put here will BE inherited by subclasses
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
-      tags => [ qw(unstable network traceroute) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          first_hop => [ qw(hop_number) ],
          last_hop => [ qw(hop_number) ],
@@ -27,11 +29,15 @@ sub brik_properties {
          try => 2,
       },
       commands => {
+         install => [ ], # Inherited
          tcp => [ qw(host port) ],
       },
       require_binaries => {
          'tcptraceroute', => [ ],
       },
+      need_packages => {
+         'ubuntu' => [ qw(tcptraceroute) ],
+      },
    };
 }
 
@@ -39,14 +45,12 @@ sub tcp {
    my $self = shift;
    my ($host, $port) = @_;
 
-   if (! (defined($host) && defined($port))) {
-      return $self->log->error($self->brik_help_run('tcp'));
-   }
-
    my $rtimeout = $self->rtimeout;
    my $try = $self->try;
    my $first = $self->first_hop;
    my $last = $self->last_hop;
+   $self->brik_help_run_undef_arg('tcp', $host) or return;
+   $self->brik_help_run_undef_arg('tcp', $port) or return;
 
    my $cmd = "tcptraceroute -n -q $try -f $first -m $last -w $rtimeout  $host $port";
 
@@ -87,7 +91,7 @@ Metabrik::Network::Traceroute - network::traceroute Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
