@@ -1,5 +1,5 @@
 #
-# $Id: Wlan.pm,v 1d19720513f5 2015/03/08 11:41:04 gomor $
+# $Id: Wlan.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::wlan Brik
 #
@@ -7,12 +7,14 @@ package Metabrik::Network::Wlan;
 use strict;
 use warnings;
 
-use base qw(Metabrik::Shell::Command);
+use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1d19720513f5 $',
-      tags => [ qw(unstable wifi wlan network monitor) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable wifi wlan wireless monitor) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          device => [ qw(device) ],
          monitor => [ qw(device) ],
@@ -26,18 +28,25 @@ sub brik_properties {
          monitor => 'mon0',
       },
       commands => {
+         install => [ ], # Inherited
          scan => [ qw(device|OPTIONAL) ],
          set_bitrate => [ qw(bitrate|OPTIONAL device|OPTIONAL) ],
          set_wepkey => [ qw(key|OPTIONAL device|OPTIONAL) ],
          connect => [ qw(device|OPTIONAL essid|OPTIONAL) ],
-         start_monitor_mode => [ ],
-         stop_monitor_mode => [ ],
+         start_monitor_mode => [ qw(device|OPTIONAL) ],
+         stop_monitor_mode => [ qw(monitor|OPTIONAL) ],
       },
       require_binaries => {
          'sudo', => [ ],
          'iwlist', => [ ],
          'iwconfig', => [ ],
       },
+      optional_binaries => {
+         'airmon-ng' => [ ],
+      },
+      need_packages => {
+         'ubuntu' => [ qw(aircrack-ng iw) ],
+      },
    };
 }
 
@@ -46,6 +55,7 @@ sub scan {
    my ($device) = @_;
 
    $device ||= $self->device;
+   $self->brik_help_run_undef_arg('scan', $device) or return;
 
    $self->log->verbose("scan: using device [$device]");
 
@@ -161,23 +171,18 @@ sub connect {
    my ($device, $essid) = @_;
 
    $device ||= $self->device;
-
    $essid ||= $self->essid;
-   if (! defined($essid)) {
-      return $self->log->error($self->brik_help_set('essid'));
-   }
+   $self->brik_help_run_undef_arg('connect', $device) or return;
+   $self->brik_help_run_undef_arg('connect', $essid) or return;
 
    my $cmd = "sudo iwconfig $device essid $essid";
 
    $self->capture_stderr(1);
-
-   my $r = $self->capture($cmd)
-      or return $self->log->error("connect: capture failed");
+   my $r = $self->capture($cmd) or return;
 
    $self->log->verbose("connect: $r");
 
-   $self->set_bitrate
-      or return $self->log->error("connect: set_bitrate failed");
+   $self->set_bitrate or return;
 
    # For WEP, we can use:
    # "iwconfig $device key $key"
@@ -190,16 +195,14 @@ sub set_bitrate {
    my ($bitrate, $device) = @_;
 
    $bitrate ||= $self->bitrate;
-   if (! defined($bitrate)) {
-      return $self->log->error($self->brik_help_set('bitrate'));
-   }
-
    $device ||= $self->device;
-
-   $self->capture_stderr(1);
+   $self->brik_help_run_undef_arg('set_bitrate', $bitrate) or return;
+   $self->brik_help_run_undef_arg('set_bitrate', $device) or return;
 
    my $cmd = "sudo iwconfig $device rate $bitrate";
 
+   $self->capture_stderr(1);
+
    return $self->capture($cmd);
 }
 
@@ -208,11 +211,9 @@ sub set_wepkey {
    my ($key, $device) = @_;
 
    $key ||= $self->key;
-   if (! defined($key)) {
-      return $self->log->error($self->brik_help_set('key'));
-   }
-
    $device ||= $self->device;
+   $self->brik_help_run_undef_arg('set_wepkey', $key) or return;
+   $self->brik_help_run_undef_arg('set_wepkey', $device) or return;
 
    my $cmd = "sudo iwconfig $device key $key";
 
@@ -226,9 +227,10 @@ sub start_monitor_mode {
    my ($device) = @_;
 
    $device ||= $self->device;
+   $self->brik_help_run_undef_arg('start_monitor_mode', $device) or return;
 
    # airmon-ng is optional, so we check here.
-   my $found = $self->brik_check_require_binaries({ 'airmon-ng' => [ ] });
+   my $found = $self->brik_has_binary('airmon-ng');
    if (! $found) {
       return $self->log->error("start_monitor_mode: you have to install aircrack-ng package");
    }
@@ -267,14 +269,13 @@ sub stop_monitor_mode {
    my $self = shift;
    my ($monitor) = @_;
 
-   if (! $self->_monitor_mode_started) {
-      return $self->log->error($self->brik_help_run('start_monitor_mode'));
-   }
-
    $monitor ||= $self->monitor;
+   my $started = $self->_monitor_mode_started;
+   $self->brik_help_run_undef_arg('start_monitor_mode', $started) or return;
+   $self->brik_help_run_undef_arg('start_monitor_mode', $monitor) or return;
 
    # airmon-ng is optional, so we check here.
-   my $found = $self->brik_check_require_binaries({ 'airmon-ng' => [ ] });
+   my $found = $self->brik_has_binary('airmon-ng');
    if (! $found) {
       return $self->log->error("stop_monitor_mode: you have to install aircrack-ng package");
    }
@@ -302,7 +303,7 @@ Metabrik::Network::Wlan - network::wlan Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
