@@ -1,5 +1,5 @@
 #
-# $Id: Wps.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
+# $Id: Wps.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::wps Brik
 #
@@ -7,13 +7,16 @@ package Metabrik::Network::Wps;
 use strict;
 use warnings;
 
-use base qw(Metabrik::Network::Wlan);
+use base qw(Metabrik::Network::Wlan Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cb13feea4e0 $',
-      tags => [ qw(unstable wifi wlan network wps) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable wifi wlan wireless) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
+         install => [ ], # Inherited
          brute_force_wps => [ qw(essid bssid|OPTIONAL) ],
       },
       require_modules => {
@@ -23,6 +26,9 @@ sub brik_properties {
          'sudo', => [ ],
          'reaver', => [ ],
       },
+      need_packages => {
+         'ubuntu' => [ qw(reaver) ],
+      },
    };
 }
 
@@ -30,11 +36,7 @@ sub brute_force_wps {
    my $self = shift;
    my ($essid, $bssid) = @_;
 
-   if (! defined($essid)) {
-      return $self->log->error($self->brik_help_run('brute_force_wps'));
-   }
-
-   my $context = $self->context;
+   $self->brik_help_run_undef_arg('brute_force_wps', $essid) or return;
 
    # If user provided bssid, we skip auto-detection
    if (! defined($bssid)) {
@@ -63,8 +65,8 @@ sub brute_force_wps {
 
    my $cmd = "sudo reaver -i $monitor -b $bssid -vv";
 
-   my $shell_command = Metabrik::Shell::Command->new_from_brik($self) or return;
-   my $r = $shell_command->system($cmd);
+   my $sc = Metabrik::Shell::Command->new_from_brik_init($self) or return;
+   my $r = $sc->system($cmd);
 
    $self->stop_monitor_mode;
 
@@ -81,7 +83,7 @@ Metabrik::Network::Wps - network::wps Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
