@@ -1,5 +1,5 @@
 #
-# $Id: Snmp.pm,v 09418c424cfe 2015/03/10 18:38:42 gomor $
+# $Id: Snmp.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # server::snmp Brik
 #
@@ -7,13 +7,15 @@ package Metabrik::Server::Snmp;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::System::Package);
 
 # Default attribute values put here will BE inherited by subclasses
 sub brik_properties {
    return {
-      revision => '$Revision: 09418c424cfe $',
-      tags => [ qw(unstable server snmp agent) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable agent) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          hostname => [ qw(listen_hostname) ],
@@ -28,37 +30,26 @@ sub brik_properties {
          community => 'public',
       },
       commands => {
+         install => [ ], # Inherited
          start => [ qw(listen_hostname|OPTIONAL listen_port|OPTIONAL datadir|OPTIONAL) ],
          stop => [ ],
       },
       require_modules => {
+         'NetSNMP::agent' => [ ],
+         'NetSNMP::ASN' => [ ],
          'Metabrik::File::Text' => [ ],
          'Metabrik::Shell::Command' => [ ],
          'Metabrik::Worker::Fork' => [ ],
-         'NetSNMP::agent' => [ ],
-         'NetSNMP::ASN' => [ ],
       },
       require_binaries => {
          'snmpd' => [ ],
       },
+      need_packages => {
+         'ubuntu' => [ qw(libsnmp-dev snmpd) ],
+      },
    };
 }
 
-sub brik_init {
-   my $self = shift;
-
-   my $restore = $SIG{INT};
-
-   $SIG{INT} = sub {
-      $self->debug && $self->log->debug("brik_init: INT caught");
-      $self->stop;
-      $SIG{INT} = $restore;
-      return 1;
-   };
-
-   return $self->SUPER::brik_init(@_);
-}
-
 sub _create_snmpd_conf {
    my $self = shift;
 
@@ -184,7 +175,7 @@ Metabrik::Server::Snmp - server::snmp Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
