@@ -1,5 +1,5 @@
 #
-# $Id: Snmptrap.pm,v 09418c424cfe 2015/03/10 18:38:42 gomor $
+# $Id: Snmptrap.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # server::snmptrap Brik
 #
@@ -7,13 +7,15 @@ package Metabrik::Server::Snmptrap;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::System::Package);
 
 # Default attribute values put here will BE inherited by subclasses
 sub brik_properties {
    return {
-      revision => '$Revision: 09418c424cfe $',
-      tags => [ qw(unstable server snmp trap trapd snmptrap snmptrapd) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable snmp trap trapd snmptrapd) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          hostname => [ qw(listen_hostname) ],
@@ -25,12 +27,16 @@ sub brik_properties {
          port => 162,
       },
       commands => {
+         install => [ ], # Inherited
          start => [ qw(listen_hostname|OPTIONAL listen_port|OPTIONAL datadir|OPTIONAL) ],
          stop => [ ],
       },
       require_modules => {
-         'Metabrik::Worker::Fork' => [ ],
          'Net::SNMPTrapd' => [ ],
+         'Metabrik::Worker::Fork' => [ ],
+      },
+      need_packages => {
+         'ubuntu' => [ qw(libsnmp-dev) ],
       },
    };
 }
@@ -115,7 +121,7 @@ Metabrik::Server::Snmptrap - server::snmptrap Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
