@@ -1,5 +1,5 @@
 #
-# $Id: Tcp.pm,v d5112de7e33b 2015/11/04 07:08:16 gomor $
+# $Id: Tcp.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # server::tcp Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: d5112de7e33b $',
-      tags => [ qw(unstable server tcp socket netcat) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable socket netcat) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          hostname => [ qw(listen_hostname) ],
          port => [ qw(listen_port) ],
@@ -263,9 +265,7 @@ sub client_disconnected {
       return $self->log->error($self->brik_help_run('start'));
    }
 
-   if (! defined($id)) {
-      return $self->log->error($self->log->brik_help_run('client_disconnected'));
-   }
+   $self->brik_help_run_undef_arg('client_disconnected', $id) or return;
 
    my $clients = $self->clients;
    my $select = $self->select;
@@ -289,7 +289,7 @@ Metabrik::Server::Tcp - server::tcp Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
