@@ -1,5 +1,5 @@
 #
-# $Id: Tor.pm,v 6681de14037f 2016/01/16 16:06:27 gomor $
+# $Id: Tor.pm,v be8fd29d6b2b 2016/03/21 19:51:52 gomor $
 #
 # server::tor Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 6681de14037f $',
+      revision => '$Revision: be8fd29d6b2b $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -92,7 +92,7 @@ sub generate_conf {
    my $virtual_network = $self->virtual_network;
 
    my $sf = Metabrik::System::File->new_from_brik_init($self) or return;
-   $sf->remove($conf) or return;
+   $sf->remove($conf);
 
    my $data =<<EOF
 DataDirectory $datadir
