@@ -1,5 +1,5 @@
 #
-# $Id: Command.pm,v 00ead8d799a8 2016/02/14 14:23:21 gomor $
+# $Id: Command.pm,v 2f5dc955ae51 2016/10/06 16:15:29 gomor $
 #
 # shell::command Brik
 #
@@ -7,19 +7,18 @@ package Metabrik::Shell::Command;
 use strict;
 use warnings;
 
-our $VERSION = '1.20';
-
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 00ead8d799a8 $',
+      revision => '$Revision: 2f5dc955ae51 $',
       tags => [ qw(exec execute) ],
       attributes => {
          as_array => [ qw(0|1) ],
          as_matrix => [ qw(0|1) ],
          capture_stderr => [ qw(0|1) ],
          capture_mode => [ qw(0|1) ],
+         capture_system => [ qw(0|1) ],
          ignore_error => [ qw(0|1) ],
          use_sudo => [ qw(0|1) ],
          use_pager => [ qw(0|1) ],
@@ -31,10 +30,11 @@ sub brik_properties {
          as_matrix => 0,
          capture_stderr => 1,
          capture_mode => 0,
+         capture_system => 0,
          ignore_error => 1,
          use_sudo => 0,
          use_pager => 0,
-         use_globbing => 1,
+         use_globbing => 0,
          sudo_args => '-E',  # Keep environment
       },
       commands => {
@@ -42,11 +42,20 @@ sub brik_properties {
          sudo_system => [ qw(command) ],
          capture => [ qw(command) ],
          sudo_capture => [ qw(command) ],
+         system_capture => [ qw(command) ],
+         sudo_system_capture => [ qw(command) ],
          execute => [ qw(command) ],
          sudo_execute => [ qw(command) ],
       },
+      require_binaries => {
+         script => [ ],
+      },
       require_modules => {
          'IPC::Run3' => [ ],
+         'Metabrik::System::Os' => [ ],
+      },
+      need_packages => {
+         ubuntu => [ qw(bsdutils) ],
       },
    };
 }
@@ -103,6 +112,20 @@ sub system {
       $command .= " | $pager";
    }
 
+   # Also capture output to terminal to a file
+   my $so = Metabrik::System::Os->new_from_brik_init($self) or return;
+   my $output_file = 'capture_system.script';
+   if ($self->capture_system) {
+      if ($so->is_freebsd) {
+         $command = "script -q $output_file $command";
+      }
+      else {
+         $command = "script -q --command '".$command."' $output_file";
+      }
+   }
+
+   $self->log->verbose("system: command[$command]");
+
    my $r = CORE::system($command);
 
    $self->debug && $self->log->debug("system: command returned code [$r] with status [$?]");
@@ -116,6 +139,16 @@ sub system {
 
    $self->debug && $self->log->debug("system: program exit with success");
 
+   # Program succeeded, we only return full path to output file, 
+   # maybe the caller will have some optimization to not process ths full 
+   # file content afterwards.
+   if ($self->capture_system) {
+      my $pwd = $self->shell->full_pwd;
+      my $homedir = $self->global->homedir;
+      $pwd =~ s{^~}{$homedir};
+      return $pwd.'/'.$output_file;
+   }
+
    return 1;
 }
 
@@ -193,6 +226,7 @@ sub capture {
    my $err;
    eval {
       my $cmd = join(' ', @toks);
+      $self->log->verbose("capture: command[$cmd]");
       IPC::Run3::run3($cmd, undef, \$out, \$err);
    };
    # Error in executing run3()
@@ -252,13 +286,44 @@ sub sudo_capture {
    return $r;
 }
 
+sub system_capture {
+   my $self = shift;
+   my ($cmd, @args) = @_;
+
+   $self->brik_help_run_undef_arg('system_capture', $cmd) or return;
+
+   my $prev = $self->capture_system;
+   $self->capture_system(1);
+   my $r = $self->system($cmd, @args);
+   $self->capture_system($prev);
+
+   return $r;
+}
+
+sub sudo_system_capture {
+   my $self = shift;
+   my ($cmd, @args) = @_;
+
+   $self->brik_help_run_undef_arg('sudo_system_capture', $cmd) or return;
+
+   my $prev = $self->capture_system;
+   $self->capture_system(1);
+   my $r = $self->sudo_system($cmd, @args);
+   $self->capture_system($prev);
+
+   return $r;
+}
+
 sub execute {
    my $self = shift;
    my ($cmd, @args) = @_;
    
    $self->brik_help_run_undef_arg('execute', $cmd) or return;
 
-   if ($self->capture_mode) {
+   if ($self->capture_system) {
+      return $self->system_capture($cmd, @args);
+   }
+   elsif ($self->capture_mode) {
       return $self->capture($cmd, @args);
    }
    else {  # non-capture mode
@@ -275,7 +340,10 @@ sub sudo_execute {
 
    $self->brik_help_run_undef_arg('sudo_execute', $cmd) or return;
 
-   if ($self->capture_mode) {
+   if ($self->capture_system) {
+      return $self->sudo_system_capture($cmd, @args);
+   }
+   elsif ($self->capture_mode) {
       return $self->sudo_capture($cmd, @args);
    }
    else {  # non-capture mode
