@@ -1,5 +1,5 @@
 #
-# $Id: Rc.pm,v a9f701f734ff 2016/01/02 18:05:58 gomor $
+# $Id: Rc.pm,v f43f03db50ed 2016/10/04 05:00:14 gomor $
 #
 # shell::rc Brik
 #
@@ -7,13 +7,11 @@ package Metabrik::Shell::Rc;
 use strict;
 use warnings;
 
-our $VERSION = '1.20';
-
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: a9f701f734ff $',
+      revision => '$Revision: f43f03db50ed $',
       tags => [ qw(custom) ],
       attributes => {
          input => [ qw(file) ],
@@ -106,10 +104,8 @@ set core::shell echo 0
 my \$home = \$ENV{HOME}
 my \$user = \$ENV{USER}
 
-my \$datadir = "\$home/metabrik"
 my \$sudo = "sudo -E \$0 --no-splash"
 
-set core::global datadir \$datadir
 set core::global ctimeout 5
 set core::global rtimeout 5
 
