@@ -1,5 +1,5 @@
 #
-# $Id: Base64.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Base64.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # string::base64 Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
-      tags => [ qw(unstable encode decode base64) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable encode decode) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          encode => [ qw($data) ],
          decode => [ qw($data) ],
@@ -27,11 +29,10 @@ sub encode {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('encode'));
-   }
+   $self->brik_help_run_undef_arg('encode', $data) or return;
 
    my $encoded = MIME::Base64::encode_base64($data);
+   chomp($encoded);
 
    return $encoded;
 }
@@ -40,11 +41,10 @@ sub decode {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('decode'));
-   }
+   $self->brik_help_run_undef_arg('decode', $data) or return;
 
    my $decoded = MIME::Base64::decode_base64($data);
+   chomp($decoded);
 
    return $decoded;
 }
@@ -59,7 +59,7 @@ Metabrik::String::Base64 - string::base64 Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
