@@ -1,5 +1,5 @@
 #
-# $Id: Compress.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Compress.pm,v 3581e1e07caf 2016/01/20 10:14:01 gomor $
 #
 # string::gzip Brik
 #
@@ -7,12 +7,14 @@ package Metabrik::String::Compress;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
-      tags => [ qw(unstable gzip gunzip uncompress compress) ],
+      revision => '$Revision: 3581e1e07caf $',
+      tags => [ qw(unstable gzip gunzip unzip uncompress) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          data => [ qw($data) ],
          memory_limit => [ qw(integer) ],
@@ -21,12 +23,16 @@ sub brik_properties {
          memory_limit => '1_000_000_000', # XXX: to implement
       },
       commands => {
+         install => [ ],  # Inherited
          gunzip => [ qw($data) ],
          gzip => [ qw($data) ],
       },
       require_modules => {
          'Gzip::Faster' => [ ],
       },
+      need_packages => {
+         ubuntu => [ qw(libz-dev) ],
+      },
    };
 }
 
@@ -34,9 +40,7 @@ sub gunzip {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('gunzip'));
-   }
+   $self->brik_help_run_undef_arg('gunzip', $data) or return;
 
    $self->debug && $self->log->debug("gunzip: length[".length($data)."]");
 
@@ -56,9 +60,7 @@ sub gzip {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('gzip'));
-   }
+   $self->brik_help_run_undef_arg('gzip', $data) or return;
 
    my $gzipped = Gzip::Faster::gzip($data)
       or return $self->log->error("gzip: error");
@@ -76,7 +78,7 @@ Metabrik::String::Compress - string::compress Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
