@@ -1,5 +1,5 @@
 #
-# $Id: Hostname.pm,v e5e3576f73a3 2015/11/10 09:17:44 gomor $
+# $Id: Hostname.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # string::hostname Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: e5e3576f73a3 $',
-      tags => [ qw(unstable hostname string fqdn domain) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable fqdn domain) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          hostname => [ qw(hostname) ],
       },
@@ -27,9 +29,7 @@ sub parse {
    my ($hostname) = @_;
 
    $hostname ||= $self->hostname;
-   if (! defined($hostname)) {
-      return $self->log->error($self->brik_help_run('parse'));
-   }
+   $self->brik_help_run_undef_arg('parse', $hostname) or return;
 
    my $tld = '';
    my $domain = '';
@@ -78,7 +78,7 @@ Metabrik::String::Hostname - string::hostname Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
