@@ -1,5 +1,5 @@
 #
-# $Id: Html.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Html.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # string::html Brik
 #
@@ -11,14 +11,16 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
-      tags => [ qw(unstable encode decode html escape) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable encode decode escape) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          encode => [ qw($data) ],
          decode => [ qw($data) ],
       },
       require_modules => {
-         'URI::Escape' => [ ],
+         'HTML::Entities' => [ ],
       },
    };
 }
@@ -27,11 +29,9 @@ sub encode {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('encode'));
-   }
+   $self->brik_help_run_undef_arg('encode', $data) or return;
 
-   my $encoded = URI::Escape::uri_escape($data);
+   my $encoded = HTML::Entities::encode_entities($data);
 
    return $encoded;
 }
@@ -40,11 +40,9 @@ sub decode {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('decode'));
-   }
+   $self->brik_help_run_undef_arg('decode', $data) or return;
 
-   my $decoded = URI::Escape::uri_unescape($data);
+   my $decoded = HTML::Entities::decode_entities($data);
 
    return $decoded;
 }
@@ -59,7 +57,7 @@ Metabrik::String::Html - string::html Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
