@@ -1,5 +1,5 @@
 #
-# $Id: Ini.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Ini.pm,v 73e7d764680a 2016/04/03 08:51:50 gomor $
 #
 # string::ini Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: 73e7d764680a $',
       tags => [ qw(unstable encode decode) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -54,7 +54,7 @@ sub decode {
 
    my ($config) = Config::Tiny->read_string($data);
 
-   return { each %$config };
+   return { %$config };
 }
 
 1;
