@@ -1,5 +1,5 @@
 #
-# $Id: Password.pm,v cb06b0aa21d0 2015/11/07 18:01:20 gomor $
+# $Id: Password.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # string::password Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: cb06b0aa21d0 $',
-      tags => [ qw(unstable password random) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable random) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          charset => [ qw($character_list) ],
          length => [ qw(integer) ],
@@ -82,7 +84,7 @@ Metabrik::String::Password - string::password Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
