@@ -1,5 +1,5 @@
 #
-# $Id: Regex.pm,v 36c642ac94d3 2015/10/12 19:05:47 gomor $
+# $Id: Regex.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # string::regex Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 36c642ac94d3 $',
-      tags => [ qw(unstable encode decode hex) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable encode decode) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
       },
       attributes_default => {
@@ -30,9 +32,7 @@ sub encode {
    my $self = shift;
    my ($regex) = @_;
 
-   if (! defined($regex)) {
-      return $self->log->error($self->brik_help_run('encode'));
-   }
+   $self->brik_help_run_undef_arg('encode', $regex) or return;
 
    my $ra = Regexp::Assemble->new
       or return $self->log->error("encode: Regexp::Assemble new failed");
@@ -48,7 +48,7 @@ sub encode {
 
    my $encoded;
    eval {
-      $encoded = $ra->re;
+      $encoded = $ra->as_string;
    };
    if ($@) {
       chomp($@);
@@ -68,7 +68,7 @@ Metabrik::String::Regex - string::regex Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
