@@ -1,5 +1,5 @@
 #
-# $Id: Rot13.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Rot13.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # string::rot13 Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
-      tags => [ qw(unstable encode decode rot13) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable encode decode) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          encode => [ qw($data) ],
          decode => [ qw($data) ],
@@ -24,9 +26,7 @@ sub encode {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('encode'));
-   }
+   $self->brik_help_run_undef_arg('encode', $data) or return;
 
    (my $encoded = $data) =~ tr/n-za-m/a-z/;
 
@@ -37,9 +37,7 @@ sub decode {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('decode'));
-   }
+   $self->brik_help_run_undef_arg('decode', $data) or return;
 
    return $self->encode($data);
 }
@@ -54,7 +52,7 @@ Metabrik::String::Rot13 - string::rot13 Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
