@@ -1,5 +1,5 @@
 #
-# $Id: Xml.pm,v 00ead8d799a8 2016/02/14 14:23:21 gomor $
+# $Id: Xml.pm,v 8618a4b46183 2016/03/19 16:37:47 gomor $
 #
 # string::xml Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 00ead8d799a8 $',
+      revision => '$Revision: 8618a4b46183 $',
       tags => [ qw(unstable encode decode) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -25,7 +25,7 @@ sub brik_properties {
       },
       need_packages => {
          ubuntu => [ qw(libexpat1-dev libxml2-dev) ],
-         freebsd => [ qw(libxml2) ],
+         freebsd => [ qw(expat libxml2) ],
       },
    };
 }
