@@ -1,5 +1,5 @@
 #
-# $Id: Docker.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Docker.pm,v 9789bc0b2d2e 2016/09/29 06:07:49 gomor $
 #
 # system::docker Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: 9789bc0b2d2e $',
       tags => [ qw(unstable jail) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -207,8 +207,9 @@ sub delete {
    $self->brik_help_run_undef_arg('delete', $name) or return;
 
    my $cmd = "docker rmi -f $name";
+   $self->SUPER::execute($cmd) or return;
 
-   return $self->SUPER::execute($cmd);
+   return $name;
 }
 
 sub update {
