@@ -1,5 +1,5 @@
 #
-# $Id: File.pm,v 1a1657831fad 2016/02/13 09:48:15 gomor $
+# $Id: File.pm,v ae4d13e0fd61 2016/04/02 12:37:00 gomor $
 #
 # system::file Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1a1657831fad $',
+      revision => '$Revision: ae4d13e0fd61 $',
       tags => [ qw(unstable chmod chgrp cp copy move rm mv remove mkdir mkd) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -40,12 +40,22 @@ sub brik_properties {
          basefile => [ qw(path) ],
          basedir => [ qw(path) ],
          link => [ qw(from to) ],
+         uniq => [ qw(input output) ],
+         count => [ qw(input) ],
+         touch => [ qw(file) ],
       },
       require_modules => {
          'File::Copy' => [ qw(mv copy) ],
          'File::Path' => [ qw(make_path) ],
          'File::Spec' => [ ],
       },
+      need_packages => {
+         ubuntu => [ qw(coreutils) ],
+      },
+      require_binaries => {
+         sort => [ ],
+         wc => [ ],
+      },
    };
 }
 
@@ -174,8 +184,8 @@ sub create {
    my $self = shift;
    my ($file, $size) = @_;
 
-   $self->brik_help_run_undef_arg("create", $file) or return;
-   $self->brik_help_run_undef_arg("create", $size) or return;
+   $self->brik_help_run_undef_arg('create', $file) or return;
+   $self->brik_help_run_undef_arg('create', $size) or return;
 
    my $overwrite = $self->overwrite;
    if (-f $file && ! $self->overwrite) {
@@ -189,10 +199,15 @@ sub create {
    my $fw = Metabrik::File::Write->new_from_brik_init($self) or return;
    $fw->overwrite(1);
    $fw->open($file) or return;
-   $fw->write(sprintf("G"x$size));
+   if ($size > 0) {
+      $fw->write(sprintf("G"x$size));
+   }
+   else {
+      $fw->write('');
+   }
    $fw->close;
 
-   return 1;
+   return $file;
 }
 
 sub glob {
@@ -291,6 +306,57 @@ sub link {
    return $to;
 }
 
+#
+# Remove duplicated lines
+#
+sub uniq {
+   my $self = shift;
+   my ($input, $output) = @_;
+
+   $self->brik_help_run_undef_arg('uniq', $input) or return;
+   $self->brik_help_run_undef_arg('uniq', $output) or return;
+
+   my $cmd = "sort -u \"$input\" > \"$output\"";
+
+   $self->execute($cmd) or return;
+
+   return $self->count($output);
+}
+
+#
+# Count number of lines from a file
+#
+sub count {
+   my $self = shift;
+   my ($input) = @_;
+
+   $self->brik_help_run_undef_arg('count', $input) or return;
+
+   my $cmd = "wc -l \"$input\"";
+
+   my $r = $self->capture($cmd) or return;
+
+   if (@$r != 1) {
+      return $r;
+   }
+
+   my ($count) = $r->[0] =~ m{^(\d+)};
+
+   return $count;
+}
+
+#
+# Just create an empty file
+#
+sub touch {
+   my $self = shift;
+   my ($file) = @_;
+
+   $self->brik_help_run_undef_arg('touch', $file) or return;
+
+   return $self->create($file, 0);
+}
+
 1;
 
 __END__
