@@ -1,5 +1,5 @@
 #
-# $Id: Pf.pm,v 4bab4cd5bf0f 2015/10/08 13:36:54 gomor $
+# $Id: Pf.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # system::freebsd::pf Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 4bab4cd5bf0f $',
-      tags => [ qw(unstable system pf packet filter freebsd) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable packet filter fw firewall) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          edit => [ ],
          reload => [ ],
@@ -50,7 +52,7 @@ Metabrik::System::Freebsd::Pf - system::freebsd::pf Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
