@@ -1,5 +1,5 @@
 #
-# $Id: Process.pm,v 9c71f585c5e3 2016/02/08 20:37:51 gomor $
+# $Id: Process.pm,v 2f5dc955ae51 2016/10/06 16:15:29 gomor $
 #
 # system::process Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 9c71f585c5e3 $',
+      revision => '$Revision: 2f5dc955ae51 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -49,7 +49,10 @@ sub brik_properties {
          'Metabrik::File::Find' => [ ],
       },
       require_binaries => {
-         'ps', => [ ],
+         ps => [ ],
+      },
+      need_packages => {
+         ubuntu => [ qw(procps) ],
       },
    };
 }
