@@ -1,5 +1,5 @@
 #
-# $Id: Package.pm,v 2dab3f76f3fa 2016/01/18 10:59:08 gomor $
+# $Id: Package.pm,v 2f5dc955ae51 2016/10/06 16:15:29 gomor $
 #
 # system::ubuntu::package Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 2dab3f76f3fa $',
+      revision => '$Revision: 2f5dc955ae51 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -31,7 +31,7 @@ sub brik_properties {
          system_upgrade => [ ],
       },
       optional_binaries => {
-         'aptitude' => [ ],
+         aptitude => [ ],
       },
       require_binaries => {
          'apt-get' => [ ],
