@@ -1,5 +1,5 @@
 #
-# $Id: Virtualbox.pm,v c027a8c1ec6c 2016/02/13 15:14:12 gomor $
+# $Id: Virtualbox.pm,v fe6cf91cad64 2016/06/05 08:56:48 gomor $
 #
 # system::virtualbox Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: c027a8c1ec6c $',
+      revision => '$Revision: fe6cf91cad64 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -37,6 +37,7 @@ sub brik_properties {
          snapshot_restore => [ qw(name snapshot_name) ],
          screenshot => [ qw(name file.png) ],
          dumpguestcore => [ qw(name file.elf) ],
+         dumpvmcore => [ qw(name file.elf) ],
          extract_memdump_from_dumpguestcore => [ qw(input output) ],
          restart => [ qw(name type|OPTIONAL) ],
       },
@@ -163,6 +164,9 @@ sub screenshot {
    return $file;
 }
 
+#
+# Dump guestcore
+#
 sub dumpguestcore {
    my $self = shift;
    my ($name, $file) = @_;
@@ -175,6 +179,22 @@ sub dumpguestcore {
    return $file;
 }
 
+#
+# Dump vmcore, same as dump guestcore but for newer versions of VirtualBox which renamed 
+# the function
+#
+sub dumpvmcore {
+   my $self = shift;
+   my ($name, $file) = @_;
+
+   $self->brik_help_run_undef_arg('dumpvmcore', $name) or return;
+   $self->brik_help_run_undef_arg('dumpvmcore', $file) or return;
+
+   $self->command("debugvm \"$name\" dumpvmcore --filename \"$file\"") or return;
+
+   return $file;
+}
+
 #
 # By taking information from:
 # http://wiki.yobi.be/wiki/RAM_analysis#RAM_dump_with_VirtualBox:_via_ELF64_coredump
