@@ -1,5 +1,5 @@
 #
-# $Id: Fork.pm,v 714d5f4c8eff 2015/11/22 11:38:52 gomor $
+# $Id: Fork.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # worker::fork Brik
 #
@@ -12,8 +12,10 @@ use base qw(Metabrik);
 # Default attribute values put here will BE inherited by subclasses
 sub brik_properties {
    return {
-      revision => '$Revision: 714d5f4c8eff $',
-      tags => [ qw(unstable worker fork process) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable process) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          pid => [ qw(forked_process_id) ],
       },
@@ -94,7 +96,7 @@ Metabrik::Worker::Fork - worker::fork Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
