@@ -1,5 +1,5 @@
 #
-# $Id: Screenshot.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Screenshot.pm,v a1d025d2b3b9 2016/02/22 18:54:32 gomor $
 #
 # xorg::screenshot Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: a1d025d2b3b9 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -129,7 +129,11 @@ sub window_id {
    }
 
    my $cmd = "import -window $window_id $output";
-   $self->execute($cmd) or return;
+   my $r = $self->execute($cmd) or return;
+
+   if ($r == 256) {
+      return $self->log->error("window_id: import failed");
+   }
 
    return $output;
 }
